Class: TalonOne::AchievementV2

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/achievement_v2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AchievementV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/talon_one/models/achievement_v2.rb', line 154

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AchievementV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AchievementV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'period')
    self.period = attributes[:'period']
  end

  if attributes.key?(:'recurrence_policy')
    self.recurrence_policy = attributes[:'recurrence_policy']
  end

  if attributes.key?(:'activation_policy')
    self.activation_policy = attributes[:'activation_policy']
  end

  if attributes.key?(:'fixed_start_date')
    self.fixed_start_date = attributes[:'fixed_start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'allow_rollback_after_completion')
    self.allow_rollback_after_completion = attributes[:'allow_rollback_after_completion']
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'subscribed_applications')
    if (value = attributes[:'subscribed_applications']).is_a?(Array)
      self.subscribed_applications = value
    end
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'has_progress')
    self.has_progress = attributes[:'has_progress']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#activation_policyObject

The policy that determines how the achievement starts, ends, or resets. - ‘user_action`: The achievement ends or resets relative to when the customer started the achievement. - `fixed_schedule`: The achievement starts, ends, or resets for all customers following a fixed schedule.



42
43
44
# File 'lib/talon_one/models/achievement_v2.rb', line 42

def activation_policy
  @activation_policy
end

#allow_rollback_after_completionObject

When ‘true`, customer progress can be rolled back in completed achievements.



51
52
53
# File 'lib/talon_one/models/achievement_v2.rb', line 51

def allow_rollback_after_completion
  @allow_rollback_after_completion
end

#createdObject

The time this entity was created.



21
22
23
# File 'lib/talon_one/models/achievement_v2.rb', line 21

def created
  @created
end

#created_byObject

Name of the user that created the achievement. Note: This is not available if the user has been deleted.



66
67
68
# File 'lib/talon_one/models/achievement_v2.rb', line 66

def created_by
  @created_by
end

#descriptionObject

A description of the achievement.



30
31
32
# File 'lib/talon_one/models/achievement_v2.rb', line 30

def description
  @description
end

#end_dateObject

The achievement’s end date. If defined, customers cannot participate in the achievement after this date. Note: It must be an RFC3339 timestamp string.



48
49
50
# File 'lib/talon_one/models/achievement_v2.rb', line 48

def end_date
  @end_date
end

#fixed_start_dateObject

The achievement’s start date when ‘activationPolicy` is set to `fixed_schedule`. Note: It must be an RFC3339 timestamp string.



45
46
47
# File 'lib/talon_one/models/achievement_v2.rb', line 45

def fixed_start_date
  @fixed_start_date
end

#has_progressObject

Indicates if a customer has made progress in the achievement.



69
70
71
# File 'lib/talon_one/models/achievement_v2.rb', line 69

def has_progress
  @has_progress
end

#idObject

The internal ID of this entity.



18
19
20
# File 'lib/talon_one/models/achievement_v2.rb', line 18

def id
  @id
end

#nameObject

The internal name of the achievement used in API requests. Note: The name should start with a letter. This cannot be changed after the achievement has been created.



24
25
26
# File 'lib/talon_one/models/achievement_v2.rb', line 24

def name
  @name
end

#periodObject

The relative duration after which the achievement ends and resets for a particular customer profile. Note: The ‘period` does not start when the achievement is created. The period is a **positive real number** followed by one letter indicating the time unit. Examples: `30s`, `40m`, `1h`, `5D`, `7W`, `10M`, `15Y`. Available units: - `s`: seconds - `m`: minutes - `h`: hours - `D`: days - `W`: weeks - `M`: months - `Y`: years You can also round certain units down to the beginning of period and up to the end of period.: - `_D` for rounding down days only. Signifies the start of the day. Example: `30D_D` - `_U` for rounding up days, weeks, months and years. Signifies the end of the day, week, month or year. Example: `23W_U` Note: You can either use the round down and round up option or set an absolute period.



36
37
38
# File 'lib/talon_one/models/achievement_v2.rb', line 36

def period
  @period
end

#recurrence_policyObject

The policy that determines if and how the achievement recurs. - ‘no_recurrence`: The achievement can be completed only once. - `on_expiration`: The achievement resets after it expires and becomes available again. - `on_completion`: When the customer progress status reaches `completed`, the achievement resets and becomes available again.



39
40
41
# File 'lib/talon_one/models/achievement_v2.rb', line 39

def recurrence_policy
  @recurrence_policy
end

#sandboxObject

Indicates if this achievement is a live or sandbox achievement. Achievements of a given type can only be connected to Applications of the same type.



54
55
56
# File 'lib/talon_one/models/achievement_v2.rb', line 54

def sandbox
  @sandbox
end

#statusObject

The status of the achievement.



72
73
74
# File 'lib/talon_one/models/achievement_v2.rb', line 72

def status
  @status
end

#subscribed_applicationsObject

A list containing the IDs of all applications that are subscribed to A list containing the IDs of all Applications that are connected to this achievement.



57
58
59
# File 'lib/talon_one/models/achievement_v2.rb', line 57

def subscribed_applications
  @subscribed_applications
end

#targetObject

The required number of actions or the transactional milestone to complete the achievement.



33
34
35
# File 'lib/talon_one/models/achievement_v2.rb', line 33

def target
  @target
end

#timezoneObject

A string containing an IANA timezone descriptor.



60
61
62
# File 'lib/talon_one/models/achievement_v2.rb', line 60

def timezone
  @timezone
end

#titleObject

The display name for the achievement in the Campaign Manager.



27
28
29
# File 'lib/talon_one/models/achievement_v2.rb', line 27

def title
  @title
end

#user_idObject

The ID of the user that created this achievement.



63
64
65
# File 'lib/talon_one/models/achievement_v2.rb', line 63

def user_id
  @user_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/talon_one/models/achievement_v2.rb', line 97

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'name' => :'name',
    :'title' => :'title',
    :'description' => :'description',
    :'target' => :'target',
    :'period' => :'period',
    :'recurrence_policy' => :'recurrencePolicy',
    :'activation_policy' => :'activationPolicy',
    :'fixed_start_date' => :'fixedStartDate',
    :'end_date' => :'endDate',
    :'allow_rollback_after_completion' => :'allowRollbackAfterCompletion',
    :'sandbox' => :'sandbox',
    :'subscribed_applications' => :'subscribedApplications',
    :'timezone' => :'timezone',
    :'user_id' => :'userId',
    :'created_by' => :'createdBy',
    :'has_progress' => :'hasProgress',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



454
455
456
# File 'lib/talon_one/models/achievement_v2.rb', line 454

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



147
148
149
150
# File 'lib/talon_one/models/achievement_v2.rb', line 147

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/talon_one/models/achievement_v2.rb', line 122

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'DateTime',
    :'name' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'target' => :'Float',
    :'period' => :'String',
    :'recurrence_policy' => :'String',
    :'activation_policy' => :'String',
    :'fixed_start_date' => :'DateTime',
    :'end_date' => :'DateTime',
    :'allow_rollback_after_completion' => :'Boolean',
    :'sandbox' => :'Boolean',
    :'subscribed_applications' => :'Array<Integer>',
    :'timezone' => :'String',
    :'user_id' => :'Integer',
    :'created_by' => :'String',
    :'has_progress' => :'Boolean',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/talon_one/models/achievement_v2.rb', line 415

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      name == o.name &&
      title == o.title &&
      description == o.description &&
      target == o.target &&
      period == o.period &&
      recurrence_policy == o.recurrence_policy &&
      activation_policy == o.activation_policy &&
      fixed_start_date == o.fixed_start_date &&
      end_date == o.end_date &&
      allow_rollback_after_completion == o.allow_rollback_after_completion &&
      sandbox == o.sandbox &&
      subscribed_applications == o.subscribed_applications &&
      timezone == o.timezone &&
      user_id == o.user_id &&
      created_by == o.created_by &&
      has_progress == o.has_progress &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/talon_one/models/achievement_v2.rb', line 482

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/talon_one/models/achievement_v2.rb', line 551

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/talon_one/models/achievement_v2.rb', line 461

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


441
442
443
# File 'lib/talon_one/models/achievement_v2.rb', line 441

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



447
448
449
# File 'lib/talon_one/models/achievement_v2.rb', line 447

def hash
  [id, created, name, title, description, target, period, recurrence_policy, activation_policy, fixed_start_date, end_date, allow_rollback_after_completion, sandbox, subscribed_applications, timezone, user_id, created_by, has_progress, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/talon_one/models/achievement_v2.rb', line 248

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 1000
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 1000.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]\w+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @recurrence_policy.nil?
    invalid_properties.push('invalid value for "recurrence_policy", recurrence_policy cannot be nil.')
  end

  if @activation_policy.nil?
    invalid_properties.push('invalid value for "activation_policy", activation_policy cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  if @subscribed_applications.nil?
    invalid_properties.push('invalid value for "subscribed_applications", subscribed_applications cannot be nil.')
  end

  if @timezone.nil?
    invalid_properties.push('invalid value for "timezone", timezone cannot be nil.')
  end

  if @timezone.to_s.length < 1
    invalid_properties.push('invalid value for "timezone", the character length must be great than or equal to 1.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



527
528
529
# File 'lib/talon_one/models/achievement_v2.rb', line 527

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/talon_one/models/achievement_v2.rb', line 533

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



521
522
523
# File 'lib/talon_one/models/achievement_v2.rb', line 521

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/talon_one/models/achievement_v2.rb', line 320

def valid?
  return false if @id.nil?
  return false if @created.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 1000
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[a-zA-Z]\w+$/)
  return false if @title.nil?
  return false if @description.nil?
  return false if @target.nil?
  return false if @recurrence_policy.nil?
  recurrence_policy_validator = EnumAttributeValidator.new('String', ["no_recurrence", "on_expiration", "on_completion"])
  return false unless recurrence_policy_validator.valid?(@recurrence_policy)
  return false if @activation_policy.nil?
  activation_policy_validator = EnumAttributeValidator.new('String', ["user_action", "fixed_schedule"])
  return false unless activation_policy_validator.valid?(@activation_policy)
  return false if @sandbox.nil?
  return false if @subscribed_applications.nil?
  return false if @timezone.nil?
  return false if @timezone.to_s.length < 1
  return false if @user_id.nil?
  status_validator = EnumAttributeValidator.new('String', ["inprogress", "expired", "not_started", "completed"])
  return false unless status_validator.valid?(@status)
  true
end