Class: TalonOne::AddLoyaltyPointsEffectProps
- Inherits:
-
Object
- Object
- TalonOne::AddLoyaltyPointsEffectProps
- Defined in:
- lib/talon_one/models/add_loyalty_points_effect_props.rb
Overview
The properties specific to the "addLoyaltyPoints" effect. This gets triggered whenever a validated rule contained an "add loyalty" effect. These points are automatically stored and managed inside Talon.One.
Instance Attribute Summary collapse
-
#awaits_activation ⇒ Object
If ‘true`, the loyalty points remain pending until a specific action is complete.
-
#bundle_index ⇒ Object
The position of the bundle in a list of item bundles created from the same bundle definition.
-
#bundle_name ⇒ Object
The name of the bundle definition.
-
#card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
-
#cart_item_position ⇒ Object
The index of the item in the cart items list on which the loyal points addition should be applied.
-
#cart_item_sub_position ⇒ Object
For cart items with ‘quantity` > 1, the sub position indicates to which item the loyalty points addition is applied.
-
#desired_value ⇒ Object
The original amount of loyalty points to be awarded.
-
#expiry_date ⇒ Object
Date after which points will expire.
-
#name ⇒ Object
The name / description of this loyalty point addition.
-
#program_id ⇒ Object
The ID of the loyalty program where these points were added.
-
#recipient_integration_id ⇒ Object
The user for whom these points were added.
-
#start_date ⇒ Object
Date after which points will be valid.
-
#sub_ledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
-
#transaction_uuid ⇒ Object
The identifier of this addition in the loyalty ledger.
-
#validity_duration ⇒ Object
The duration for which the points remain active, calculated relative to the activation date.
-
#value ⇒ Object
The amount of points that were added.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddLoyaltyPointsEffectProps
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AddLoyaltyPointsEffectProps
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 118 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddLoyaltyPointsEffectProps` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddLoyaltyPointsEffectProps`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] end if attributes.key?(:'sub_ledger_id') self.sub_ledger_id = attributes[:'sub_ledger_id'] end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'desired_value') self.desired_value = attributes[:'desired_value'] end if attributes.key?(:'recipient_integration_id') self.recipient_integration_id = attributes[:'recipient_integration_id'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'transaction_uuid') self.transaction_uuid = attributes[:'transaction_uuid'] end if attributes.key?(:'cart_item_position') self.cart_item_position = attributes[:'cart_item_position'] end if attributes.key?(:'cart_item_sub_position') self.cart_item_sub_position = attributes[:'cart_item_sub_position'] end if attributes.key?(:'card_identifier') self.card_identifier = attributes[:'card_identifier'] end if attributes.key?(:'bundle_index') self.bundle_index = attributes[:'bundle_index'] end if attributes.key?(:'bundle_name') self.bundle_name = attributes[:'bundle_name'] end if attributes.key?(:'awaits_activation') self.awaits_activation = attributes[:'awaits_activation'] end if attributes.key?(:'validity_duration') self.validity_duration = attributes[:'validity_duration'] end end |
Instance Attribute Details
#awaits_activation ⇒ Object
If ‘true`, the loyalty points remain pending until a specific action is complete. The `startDate` parameter automatically sets to `on_action`.
61 62 63 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 61 def awaits_activation @awaits_activation end |
#bundle_index ⇒ Object
The position of the bundle in a list of item bundles created from the same bundle definition.
55 56 57 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 55 def bundle_index @bundle_index end |
#bundle_name ⇒ Object
The name of the bundle definition.
58 59 60 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 58 def bundle_name @bundle_name end |
#card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
52 53 54 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 52 def card_identifier @card_identifier end |
#cart_item_position ⇒ Object
The index of the item in the cart items list on which the loyal points addition should be applied.
46 47 48 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 46 def cart_item_position @cart_item_position end |
#cart_item_sub_position ⇒ Object
For cart items with ‘quantity` > 1, the sub position indicates to which item the loyalty points addition is applied.
49 50 51 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 49 def cart_item_sub_position @cart_item_sub_position end |
#desired_value ⇒ Object
The original amount of loyalty points to be awarded.
31 32 33 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 31 def desired_value @desired_value end |
#expiry_date ⇒ Object
Date after which points will expire.
40 41 42 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 40 def expiry_date @expiry_date end |
#name ⇒ Object
The name / description of this loyalty point addition.
19 20 21 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 19 def name @name end |
#program_id ⇒ Object
The ID of the loyalty program where these points were added.
22 23 24 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 22 def program_id @program_id end |
#recipient_integration_id ⇒ Object
The user for whom these points were added.
34 35 36 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 34 def recipient_integration_id @recipient_integration_id end |
#start_date ⇒ Object
Date after which points will be valid.
37 38 39 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 37 def start_date @start_date end |
#sub_ledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
25 26 27 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 25 def sub_ledger_id @sub_ledger_id end |
#transaction_uuid ⇒ Object
The identifier of this addition in the loyalty ledger.
43 44 45 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 43 def transaction_uuid @transaction_uuid end |
#validity_duration ⇒ Object
The duration for which the points remain active, calculated relative to the activation date. Note: This value is returned only if ‘awaitsActivation` is `true` and `expiryDate` is not set.
64 65 66 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 64 def validity_duration @validity_duration end |
#value ⇒ Object
The amount of points that were added.
28 29 30 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 28 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 67 def self.attribute_map { :'name' => :'name', :'program_id' => :'programId', :'sub_ledger_id' => :'subLedgerId', :'value' => :'value', :'desired_value' => :'desiredValue', :'recipient_integration_id' => :'recipientIntegrationId', :'start_date' => :'startDate', :'expiry_date' => :'expiryDate', :'transaction_uuid' => :'transactionUUID', :'cart_item_position' => :'cartItemPosition', :'cart_item_sub_position' => :'cartItemSubPosition', :'card_identifier' => :'cardIdentifier', :'bundle_index' => :'bundleIndex', :'bundle_name' => :'bundleName', :'awaits_activation' => :'awaitsActivation', :'validity_duration' => :'validityDuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 331 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 111 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 89 def self.openapi_types { :'name' => :'String', :'program_id' => :'Integer', :'sub_ledger_id' => :'String', :'value' => :'Float', :'desired_value' => :'Float', :'recipient_integration_id' => :'String', :'start_date' => :'DateTime', :'expiry_date' => :'DateTime', :'transaction_uuid' => :'String', :'cart_item_position' => :'Float', :'cart_item_sub_position' => :'Float', :'card_identifier' => :'String', :'bundle_index' => :'Integer', :'bundle_name' => :'String', :'awaits_activation' => :'Boolean', :'validity_duration' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 295 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && program_id == o.program_id && sub_ledger_id == o.sub_ledger_id && value == o.value && desired_value == o.desired_value && recipient_integration_id == o.recipient_integration_id && start_date == o.start_date && expiry_date == o.expiry_date && transaction_uuid == o.transaction_uuid && cart_item_position == o.cart_item_position && cart_item_sub_position == o.cart_item_sub_position && card_identifier == o.card_identifier && bundle_index == o.bundle_index && bundle_name == o.bundle_name && awaits_activation == o.awaits_activation && validity_duration == o.validity_duration end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 359 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 428 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 338 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
318 319 320 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 318 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
324 325 326 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 324 def hash [name, program_id, sub_ledger_id, value, desired_value, recipient_integration_id, start_date, expiry_date, transaction_uuid, cart_item_position, cart_item_sub_position, card_identifier, bundle_index, bundle_name, awaits_activation, validity_duration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 198 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @program_id.nil? invalid_properties.push('invalid value for "program_id", program_id cannot be nil.') end if @sub_ledger_id.nil? invalid_properties.push('invalid value for "sub_ledger_id", sub_ledger_id cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @recipient_integration_id.nil? invalid_properties.push('invalid value for "recipient_integration_id", recipient_integration_id cannot be nil.') end if @recipient_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "recipient_integration_id", the character length must be smaller than or equal to 1000.') end if @transaction_uuid.nil? invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.') end if !@card_identifier.nil? && @card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "card_identifier", the character length must be smaller than or equal to 108.') end if !@card_identifier.nil? && @card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "card_identifier", the character length must be great than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@card_identifier.nil? && @card_identifier !~ pattern invalid_properties.push("invalid value for \"card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
404 405 406 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 404 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
398 399 400 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 398 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/talon_one/models/add_loyalty_points_effect_props.rb', line 246 def valid? return false if @name.nil? return false if @program_id.nil? return false if @sub_ledger_id.nil? return false if @value.nil? return false if @recipient_integration_id.nil? return false if @recipient_integration_id.to_s.length > 1000 return false if @transaction_uuid.nil? return false if !@card_identifier.nil? && @card_identifier.to_s.length > 108 return false if !@card_identifier.nil? && @card_identifier.to_s.length < 4 return false if !@card_identifier.nil? && @card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |