Class: TalonOne::AdditionalCampaignProperties
- Inherits:
-
Object
- Object
- TalonOne::AdditionalCampaignProperties
- Defined in:
- lib/talon_one/models/additional_campaign_properties.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#add_free_item_effect_count ⇒ Object
This property is deprecated.
-
#awarded_giveaways_count ⇒ Object
This property is deprecated.
-
#budgets ⇒ Object
A list of all the budgets that are defined by this campaign and their usage.
-
#call_api_effect_count ⇒ Object
This property is deprecated.
-
#coupon_creation_count ⇒ Object
This property is deprecated.
-
#coupon_redemption_count ⇒ Object
This property is deprecated.
-
#created_by ⇒ Object
Name of the user who created this campaign if available.
-
#created_loyalty_points_count ⇒ Object
This property is deprecated.
-
#created_loyalty_points_effect_count ⇒ Object
This property is deprecated.
-
#custom_effect_count ⇒ Object
This property is deprecated.
-
#discount_count ⇒ Object
This property is deprecated.
-
#discount_effect_count ⇒ Object
This property is deprecated.
-
#experiment_id ⇒ Object
The ID of the Experiment this Campaign is part of.
-
#frontend_state ⇒ Object
The campaign state displayed in the Campaign Manager.
-
#last_activity ⇒ Object
Timestamp of the most recent event received by this campaign.
-
#redeemed_loyalty_points_count ⇒ Object
This property is deprecated.
-
#redeemed_loyalty_points_effect_count ⇒ Object
This property is deprecated.
-
#referral_creation_count ⇒ Object
This property is deprecated.
-
#referral_redemption_count ⇒ Object
This property is deprecated.
-
#reservecoupon_effect_count ⇒ Object
This property is deprecated.
-
#stores_imported ⇒ Object
Indicates whether the linked stores were imported via a CSV file.
-
#template_id ⇒ Object
The ID of the Campaign Template this Campaign was created from.
-
#updated ⇒ Object
Timestamp of the most recent update to the campaign’s property.
-
#updated_by ⇒ Object
Name of the user who last updated this campaign if available.
-
#value_maps_ids ⇒ Object
A list of value map IDs for the campaign.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdditionalCampaignProperties
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AdditionalCampaignProperties
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 184 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AdditionalCampaignProperties` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AdditionalCampaignProperties`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'budgets') if (value = attributes[:'budgets']).is_a?(Array) self.budgets = value end end if attributes.key?(:'coupon_redemption_count') self.coupon_redemption_count = attributes[:'coupon_redemption_count'] end if attributes.key?(:'referral_redemption_count') self.referral_redemption_count = attributes[:'referral_redemption_count'] end if attributes.key?(:'discount_count') self.discount_count = attributes[:'discount_count'] end if attributes.key?(:'discount_effect_count') self.discount_effect_count = attributes[:'discount_effect_count'] end if attributes.key?(:'coupon_creation_count') self.coupon_creation_count = attributes[:'coupon_creation_count'] end if attributes.key?(:'custom_effect_count') self.custom_effect_count = attributes[:'custom_effect_count'] end if attributes.key?(:'referral_creation_count') self.referral_creation_count = attributes[:'referral_creation_count'] end if attributes.key?(:'add_free_item_effect_count') self.add_free_item_effect_count = attributes[:'add_free_item_effect_count'] end if attributes.key?(:'awarded_giveaways_count') self.awarded_giveaways_count = attributes[:'awarded_giveaways_count'] end if attributes.key?(:'created_loyalty_points_count') self.created_loyalty_points_count = attributes[:'created_loyalty_points_count'] end if attributes.key?(:'created_loyalty_points_effect_count') self.created_loyalty_points_effect_count = attributes[:'created_loyalty_points_effect_count'] end if attributes.key?(:'redeemed_loyalty_points_count') self.redeemed_loyalty_points_count = attributes[:'redeemed_loyalty_points_count'] end if attributes.key?(:'redeemed_loyalty_points_effect_count') self.redeemed_loyalty_points_effect_count = attributes[:'redeemed_loyalty_points_effect_count'] end if attributes.key?(:'call_api_effect_count') self.call_api_effect_count = attributes[:'call_api_effect_count'] end if attributes.key?(:'reservecoupon_effect_count') self.reservecoupon_effect_count = attributes[:'reservecoupon_effect_count'] end if attributes.key?(:'last_activity') self.last_activity = attributes[:'last_activity'] end if attributes.key?(:'updated') self.updated = attributes[:'updated'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'frontend_state') self.frontend_state = attributes[:'frontend_state'] end if attributes.key?(:'stores_imported') self.stores_imported = attributes[:'stores_imported'] end if attributes.key?(:'value_maps_ids') if (value = attributes[:'value_maps_ids']).is_a?(Array) self.value_maps_ids = value end end if attributes.key?(:'experiment_id') self.experiment_id = attributes[:'experiment_id'] end end |
Instance Attribute Details
#add_free_item_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of times the [add free item effect](docs.talon.one/docs/dev/integration-api/api-effects#addfreeitem) can be triggered in this campaign.
42 43 44 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 42 def add_free_item_effect_count @add_free_item_effect_count end |
#awarded_giveaways_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of giveaways awarded by rules in this campaign.
45 46 47 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 45 def awarded_giveaways_count @awarded_giveaways_count end |
#budgets ⇒ Object
A list of all the budgets that are defined by this campaign and their usage. Note: Budgets that are not defined do not appear in this list and their usage is not counted until they are defined.
18 19 20 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 18 def budgets @budgets end |
#call_api_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of webhooks triggered by rules in this campaign.
60 61 62 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 60 def call_api_effect_count @call_api_effect_count end |
#coupon_creation_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of coupons created by rules in this campaign.
33 34 35 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 33 def coupon_creation_count @coupon_creation_count end |
#coupon_redemption_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Number of coupons redeemed in the campaign.
21 22 23 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 21 def coupon_redemption_count @coupon_redemption_count end |
#created_by ⇒ Object
Name of the user who created this campaign if available.
72 73 74 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 72 def created_by @created_by end |
#created_loyalty_points_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty points created by rules in this campaign.
48 49 50 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 48 def created_loyalty_points_count @created_loyalty_points_count end |
#created_loyalty_points_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty point creation effects triggered by rules in this campaign.
51 52 53 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 51 def created_loyalty_points_effect_count @created_loyalty_points_effect_count end |
#custom_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of custom effects triggered by rules in this campaign.
36 37 38 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 36 def custom_effect_count @custom_effect_count end |
#discount_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total amount of discounts redeemed in the campaign.
27 28 29 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 27 def discount_count @discount_count end |
#discount_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of times discounts were redeemed in this campaign.
30 31 32 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 30 def discount_effect_count @discount_effect_count end |
#experiment_id ⇒ Object
The ID of the Experiment this Campaign is part of.
90 91 92 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 90 def experiment_id @experiment_id end |
#frontend_state ⇒ Object
The campaign state displayed in the Campaign Manager.
81 82 83 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 81 def frontend_state @frontend_state end |
#last_activity ⇒ Object
Timestamp of the most recent event received by this campaign.
66 67 68 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 66 def last_activity @last_activity end |
#redeemed_loyalty_points_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty points redeemed by rules in this campaign.
54 55 56 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 54 def redeemed_loyalty_points_count @redeemed_loyalty_points_count end |
#redeemed_loyalty_points_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of loyalty point redemption effects triggered by rules in this campaign.
57 58 59 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 57 def redeemed_loyalty_points_effect_count @redeemed_loyalty_points_effect_count end |
#referral_creation_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of referrals created by rules in this campaign.
39 40 41 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 39 def referral_creation_count @referral_creation_count end |
#referral_redemption_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Number of referral codes redeemed in the campaign.
24 25 26 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 24 def referral_redemption_count @referral_redemption_count end |
#reservecoupon_effect_count ⇒ Object
This property is deprecated. The count should be available under budgets property. Total number of reserve coupon effects triggered by rules in this campaign.
63 64 65 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 63 def reservecoupon_effect_count @reservecoupon_effect_count end |
#stores_imported ⇒ Object
Indicates whether the linked stores were imported via a CSV file.
84 85 86 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 84 def stores_imported @stores_imported end |
#template_id ⇒ Object
The ID of the Campaign Template this Campaign was created from.
78 79 80 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 78 def template_id @template_id end |
#updated ⇒ Object
Timestamp of the most recent update to the campaign’s property. Updates to external entities used in this campaign are not registered by this property, such as collection or coupon updates.
69 70 71 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 69 def updated @updated end |
#updated_by ⇒ Object
Name of the user who last updated this campaign if available.
75 76 77 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 75 def updated_by @updated_by end |
#value_maps_ids ⇒ Object
A list of value map IDs for the campaign.
87 88 89 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 87 def value_maps_ids @value_maps_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 115 def self.attribute_map { :'budgets' => :'budgets', :'coupon_redemption_count' => :'couponRedemptionCount', :'referral_redemption_count' => :'referralRedemptionCount', :'discount_count' => :'discountCount', :'discount_effect_count' => :'discountEffectCount', :'coupon_creation_count' => :'couponCreationCount', :'custom_effect_count' => :'customEffectCount', :'referral_creation_count' => :'referralCreationCount', :'add_free_item_effect_count' => :'addFreeItemEffectCount', :'awarded_giveaways_count' => :'awardedGiveawaysCount', :'created_loyalty_points_count' => :'createdLoyaltyPointsCount', :'created_loyalty_points_effect_count' => :'createdLoyaltyPointsEffectCount', :'redeemed_loyalty_points_count' => :'redeemedLoyaltyPointsCount', :'redeemed_loyalty_points_effect_count' => :'redeemedLoyaltyPointsEffectCount', :'call_api_effect_count' => :'callApiEffectCount', :'reservecoupon_effect_count' => :'reservecouponEffectCount', :'last_activity' => :'lastActivity', :'updated' => :'updated', :'created_by' => :'createdBy', :'updated_by' => :'updatedBy', :'template_id' => :'templateId', :'frontend_state' => :'frontendState', :'stores_imported' => :'storesImported', :'value_maps_ids' => :'valueMapsIds', :'experiment_id' => :'experimentId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
384 385 386 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 384 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
177 178 179 180 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 177 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 146 def self.openapi_types { :'budgets' => :'Array<CampaignBudget>', :'coupon_redemption_count' => :'Integer', :'referral_redemption_count' => :'Integer', :'discount_count' => :'Float', :'discount_effect_count' => :'Integer', :'coupon_creation_count' => :'Integer', :'custom_effect_count' => :'Integer', :'referral_creation_count' => :'Integer', :'add_free_item_effect_count' => :'Integer', :'awarded_giveaways_count' => :'Integer', :'created_loyalty_points_count' => :'Float', :'created_loyalty_points_effect_count' => :'Integer', :'redeemed_loyalty_points_count' => :'Float', :'redeemed_loyalty_points_effect_count' => :'Integer', :'call_api_effect_count' => :'Integer', :'reservecoupon_effect_count' => :'Integer', :'last_activity' => :'DateTime', :'updated' => :'DateTime', :'created_by' => :'String', :'updated_by' => :'String', :'template_id' => :'Integer', :'frontend_state' => :'String', :'stores_imported' => :'Boolean', :'value_maps_ids' => :'Array<Integer>', :'experiment_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 339 def ==(o) return true if self.equal?(o) self.class == o.class && budgets == o.budgets && coupon_redemption_count == o.coupon_redemption_count && referral_redemption_count == o.referral_redemption_count && discount_count == o.discount_count && discount_effect_count == o.discount_effect_count && coupon_creation_count == o.coupon_creation_count && custom_effect_count == o.custom_effect_count && referral_creation_count == o.referral_creation_count && add_free_item_effect_count == o.add_free_item_effect_count && awarded_giveaways_count == o.awarded_giveaways_count && created_loyalty_points_count == o.created_loyalty_points_count && created_loyalty_points_effect_count == o.created_loyalty_points_effect_count && redeemed_loyalty_points_count == o.redeemed_loyalty_points_count && redeemed_loyalty_points_effect_count == o.redeemed_loyalty_points_effect_count && call_api_effect_count == o.call_api_effect_count && reservecoupon_effect_count == o.reservecoupon_effect_count && last_activity == o.last_activity && updated == o.updated && created_by == o.created_by && updated_by == o.updated_by && template_id == o.template_id && frontend_state == o.frontend_state && stores_imported == o.stores_imported && value_maps_ids == o.value_maps_ids && experiment_id == o.experiment_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 412 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 481 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 391 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
371 372 373 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 371 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 377 def hash [budgets, coupon_redemption_count, referral_redemption_count, discount_count, discount_effect_count, coupon_creation_count, custom_effect_count, referral_creation_count, add_free_item_effect_count, awarded_giveaways_count, created_loyalty_points_count, created_loyalty_points_effect_count, redeemed_loyalty_points_count, redeemed_loyalty_points_effect_count, call_api_effect_count, reservecoupon_effect_count, last_activity, updated, created_by, updated_by, template_id, frontend_state, stores_imported, value_maps_ids, experiment_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 304 def list_invalid_properties invalid_properties = Array.new if @frontend_state.nil? invalid_properties.push('invalid value for "frontend_state", frontend_state cannot be nil.') end if @stores_imported.nil? invalid_properties.push('invalid value for "stores_imported", stores_imported cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
457 458 459 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 457 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 463 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
451 452 453 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 451 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
319 320 321 322 323 324 325 |
# File 'lib/talon_one/models/additional_campaign_properties.rb', line 319 def valid? return false if @frontend_state.nil? frontend_state_validator = EnumAttributeValidator.new('String', ["expired", "scheduled", "running", "disabled", "archived", "staged"]) return false unless frontend_state_validator.valid?(@frontend_state) return false if @stores_imported.nil? true end |