Class: TalonOne::BestPriorPrice
- Inherits:
-
Object
- Object
- TalonOne::BestPriorPrice
- Defined in:
- lib/talon_one/models/best_prior_price.rb
Instance Attribute Summary collapse
-
#context_id ⇒ Object
The context ID of the context active at the time of observation.
-
#id ⇒ Object
The ID of the historical price.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#observed_at ⇒ Object
The date and time when the price was observed.
-
#price ⇒ Object
Price of the item.
-
#sku ⇒ Object
sku.
-
#target ⇒ Object
Returns the value of attribute target.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BestPriorPrice
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BestPriorPrice
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/talon_one/models/best_prior_price.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::BestPriorPrice` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::BestPriorPrice`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'sku') self.sku = attributes[:'sku'] end if attributes.key?(:'observed_at') self.observed_at = attributes[:'observed_at'] end if attributes.key?(:'context_id') self.context_id = attributes[:'context_id'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'target') self.target = attributes[:'target'] end end |
Instance Attribute Details
#context_id ⇒ Object
The context ID of the context active at the time of observation.
27 28 29 |
# File 'lib/talon_one/models/best_prior_price.rb', line 27 def context_id @context_id end |
#id ⇒ Object
The ID of the historical price.
18 19 20 |
# File 'lib/talon_one/models/best_prior_price.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
32 33 34 |
# File 'lib/talon_one/models/best_prior_price.rb', line 32 def @metadata end |
#observed_at ⇒ Object
The date and time when the price was observed.
24 25 26 |
# File 'lib/talon_one/models/best_prior_price.rb', line 24 def observed_at @observed_at end |
#price ⇒ Object
Price of the item.
30 31 32 |
# File 'lib/talon_one/models/best_prior_price.rb', line 30 def price @price end |
#sku ⇒ Object
sku
21 22 23 |
# File 'lib/talon_one/models/best_prior_price.rb', line 21 def sku @sku end |
#target ⇒ Object
Returns the value of attribute target.
34 35 36 |
# File 'lib/talon_one/models/best_prior_price.rb', line 34 def target @target end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/talon_one/models/best_prior_price.rb', line 37 def self.attribute_map { :'id' => :'id', :'sku' => :'sku', :'observed_at' => :'observedAt', :'context_id' => :'contextId', :'price' => :'price', :'metadata' => :'metadata', :'target' => :'target' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 |
# File 'lib/talon_one/models/best_prior_price.rb', line 189 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
63 64 65 66 |
# File 'lib/talon_one/models/best_prior_price.rb', line 63 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/talon_one/models/best_prior_price.rb', line 50 def self.openapi_types { :'id' => :'Integer', :'sku' => :'String', :'observed_at' => :'DateTime', :'context_id' => :'String', :'price' => :'Float', :'metadata' => :'BestPriorPriceMetadata', :'target' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/talon_one/models/best_prior_price.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && sku == o.sku && observed_at == o.observed_at && context_id == o.context_id && price == o.price && == o. && target == o.target end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/talon_one/models/best_prior_price.rb', line 217 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/talon_one/models/best_prior_price.rb', line 286 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/talon_one/models/best_prior_price.rb', line 196 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
176 177 178 |
# File 'lib/talon_one/models/best_prior_price.rb', line 176 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/talon_one/models/best_prior_price.rb', line 182 def hash [id, sku, observed_at, context_id, price, , target].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/talon_one/models/best_prior_price.rb', line 114 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @sku.nil? invalid_properties.push('invalid value for "sku", sku cannot be nil.') end if @observed_at.nil? invalid_properties.push('invalid value for "observed_at", observed_at cannot be nil.') end if @context_id.nil? invalid_properties.push('invalid value for "context_id", context_id cannot be nil.') end if @price.nil? invalid_properties.push('invalid value for "price", price cannot be nil.') end if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
262 263 264 |
# File 'lib/talon_one/models/best_prior_price.rb', line 262 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/talon_one/models/best_prior_price.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/talon_one/models/best_prior_price.rb', line 256 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/talon_one/models/best_prior_price.rb', line 149 def valid? return false if @id.nil? return false if @sku.nil? return false if @observed_at.nil? return false if @context_id.nil? return false if @price.nil? return false if @metadata.nil? return false if @target.nil? true end |