Class: TalonOne::Blueprint

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/blueprint.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Blueprint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/talon_one/models/blueprint.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Blueprint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Blueprint`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'cart_item_filters')
    if (value = attributes[:'cart_item_filters']).is_a?(Array)
      self.cart_item_filters = value
    end
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  end

  if attributes.key?(:'modified_by')
    self.modified_by = attributes[:'modified_by']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this blueprint.



21
22
23
# File 'lib/talon_one/models/blueprint.rb', line 21

def 
  @account_id
end

#application_idObject

The ID of the Application that owns this blueprint.



24
25
26
# File 'lib/talon_one/models/blueprint.rb', line 24

def application_id
  @application_id
end

#cart_item_filtersObject

Array of cart item filter templates in this blueprint. Cart item filters only contain name (no description, as description is at the blueprint level).



42
43
44
# File 'lib/talon_one/models/blueprint.rb', line 42

def cart_item_filters
  @cart_item_filters
end

#categoryObject

Category used to group blueprints.



33
34
35
# File 'lib/talon_one/models/blueprint.rb', line 33

def category
  @category
end

#createdObject

Timestamp when the blueprint was created.



45
46
47
# File 'lib/talon_one/models/blueprint.rb', line 45

def created
  @created
end

#created_byObject

ID of the user who created the blueprint.



48
49
50
# File 'lib/talon_one/models/blueprint.rb', line 48

def created_by
  @created_by
end

#descriptionObject

A longer, more detailed description of the blueprint.



30
31
32
# File 'lib/talon_one/models/blueprint.rb', line 30

def description
  @description
end

#idObject

The internal ID of this blueprint.



18
19
20
# File 'lib/talon_one/models/blueprint.rb', line 18

def id
  @id
end

#modifiedObject

Timestamp when the blueprint was last updated.



51
52
53
# File 'lib/talon_one/models/blueprint.rb', line 51

def modified
  @modified
end

#modified_byObject

ID of the user who last updated the blueprint.



54
55
56
# File 'lib/talon_one/models/blueprint.rb', line 54

def modified_by
  @modified_by
end

#rulesObject

Array of rule templates in this blueprint. Rules only contain title (no description, as description is at the blueprint level).



39
40
41
# File 'lib/talon_one/models/blueprint.rb', line 39

def rules
  @rules
end

#sourceObject

Indicates whether the blueprint is custom or shipped by Talon.One.



36
37
38
# File 'lib/talon_one/models/blueprint.rb', line 36

def source
  @source
end

#titleObject

A short description of the blueprint.



27
28
29
# File 'lib/talon_one/models/blueprint.rb', line 27

def title
  @title
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/talon_one/models/blueprint.rb', line 79

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'application_id' => :'applicationId',
    :'title' => :'title',
    :'description' => :'description',
    :'category' => :'category',
    :'source' => :'source',
    :'rules' => :'rules',
    :'cart_item_filters' => :'cartItemFilters',
    :'created' => :'created',
    :'created_by' => :'createdBy',
    :'modified' => :'modified',
    :'modified_by' => :'modifiedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
# File 'lib/talon_one/models/blueprint.rb', line 316

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/talon_one/models/blueprint.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/talon_one/models/blueprint.rb', line 98

def self.openapi_types
  {
    :'id' => :'Integer',
    :'account_id' => :'Integer',
    :'application_id' => :'Integer',
    :'title' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'source' => :'String',
    :'rules' => :'Array<CatalogRule>',
    :'cart_item_filters' => :'Array<CartItemFilterTemplate>',
    :'created' => :'DateTime',
    :'created_by' => :'Integer',
    :'modified' => :'DateTime',
    :'modified_by' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/talon_one/models/blueprint.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      application_id == o.application_id &&
      title == o.title &&
      description == o.description &&
      category == o.category &&
      source == o.source &&
      rules == o.rules &&
      cart_item_filters == o.cart_item_filters &&
      created == o.created &&
      created_by == o.created_by &&
      modified == o.modified &&
      modified_by == o.modified_by
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/talon_one/models/blueprint.rb', line 344

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/talon_one/models/blueprint.rb', line 413

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/talon_one/models/blueprint.rb', line 323

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/talon_one/models/blueprint.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/talon_one/models/blueprint.rb', line 309

def hash
  [id, , application_id, title, description, category, source, rules, cart_item_filters, created, created_by, modified, modified_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/talon_one/models/blueprint.rb', line 196

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @source.nil?
    invalid_properties.push('invalid value for "source", source cannot be nil.')
  end

  if @rules.nil?
    invalid_properties.push('invalid value for "rules", rules cannot be nil.')
  end

  if @cart_item_filters.nil?
    invalid_properties.push('invalid value for "cart_item_filters", cart_item_filters cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



389
390
391
# File 'lib/talon_one/models/blueprint.rb', line 389

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/talon_one/models/blueprint.rb', line 395

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



383
384
385
# File 'lib/talon_one/models/blueprint.rb', line 383

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/talon_one/models/blueprint.rb', line 243

def valid?
  return false if @id.nil?
  return false if @account_id.nil?
  return false if @application_id.nil?
  return false if @title.nil?
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["promotions", "pricing", "loyalty", "custom"])
  return false unless category_validator.valid?(@category)
  return false if @source.nil?
  source_validator = EnumAttributeValidator.new('String', ["custom", "default"])
  return false unless source_validator.valid?(@source)
  return false if @rules.nil?
  return false if @cart_item_filters.nil?
  return false if @created.nil?
  return false if @created_by.nil?
  true
end