Class: TalonOne::Campaign

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/campaign.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Campaign

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/talon_one/models/campaign.rb', line 322

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Campaign` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Campaign`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'enabled'
  end

  if attributes.key?(:'active_ruleset_id')
    self.active_ruleset_id = attributes[:'active_ruleset_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'reevaluate_on_return')
    self.reevaluate_on_return = attributes[:'reevaluate_on_return']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  end

  if attributes.key?(:'coupon_settings')
    self.coupon_settings = attributes[:'coupon_settings']
  end

  if attributes.key?(:'referral_settings')
    self.referral_settings = attributes[:'referral_settings']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'campaign_groups')
    if (value = attributes[:'campaign_groups']).is_a?(Array)
      self.campaign_groups = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'advanced'
  end

  if attributes.key?(:'linked_store_ids')
    if (value = attributes[:'linked_store_ids']).is_a?(Array)
      self.linked_store_ids = value
    end
  end

  if attributes.key?(:'coupon_attributes')
    self.coupon_attributes = attributes[:'coupon_attributes']
  end

  if attributes.key?(:'budgets')
    if (value = attributes[:'budgets']).is_a?(Array)
      self.budgets = value
    end
  end

  if attributes.key?(:'coupon_redemption_count')
    self.coupon_redemption_count = attributes[:'coupon_redemption_count']
  end

  if attributes.key?(:'referral_redemption_count')
    self.referral_redemption_count = attributes[:'referral_redemption_count']
  end

  if attributes.key?(:'discount_count')
    self.discount_count = attributes[:'discount_count']
  end

  if attributes.key?(:'discount_effect_count')
    self.discount_effect_count = attributes[:'discount_effect_count']
  end

  if attributes.key?(:'coupon_creation_count')
    self.coupon_creation_count = attributes[:'coupon_creation_count']
  end

  if attributes.key?(:'custom_effect_count')
    self.custom_effect_count = attributes[:'custom_effect_count']
  end

  if attributes.key?(:'referral_creation_count')
    self.referral_creation_count = attributes[:'referral_creation_count']
  end

  if attributes.key?(:'add_free_item_effect_count')
    self.add_free_item_effect_count = attributes[:'add_free_item_effect_count']
  end

  if attributes.key?(:'awarded_giveaways_count')
    self.awarded_giveaways_count = attributes[:'awarded_giveaways_count']
  end

  if attributes.key?(:'created_loyalty_points_count')
    self.created_loyalty_points_count = attributes[:'created_loyalty_points_count']
  end

  if attributes.key?(:'created_loyalty_points_effect_count')
    self.created_loyalty_points_effect_count = attributes[:'created_loyalty_points_effect_count']
  end

  if attributes.key?(:'redeemed_loyalty_points_count')
    self.redeemed_loyalty_points_count = attributes[:'redeemed_loyalty_points_count']
  end

  if attributes.key?(:'redeemed_loyalty_points_effect_count')
    self.redeemed_loyalty_points_effect_count = attributes[:'redeemed_loyalty_points_effect_count']
  end

  if attributes.key?(:'call_api_effect_count')
    self.call_api_effect_count = attributes[:'call_api_effect_count']
  end

  if attributes.key?(:'reservecoupon_effect_count')
    self.reservecoupon_effect_count = attributes[:'reservecoupon_effect_count']
  end

  if attributes.key?(:'last_activity')
    self.last_activity = attributes[:'last_activity']
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'frontend_state')
    self.frontend_state = attributes[:'frontend_state']
  end

  if attributes.key?(:'stores_imported')
    self.stores_imported = attributes[:'stores_imported']
  end

  if attributes.key?(:'value_maps_ids')
    if (value = attributes[:'value_maps_ids']).is_a?(Array)
      self.value_maps_ids = value
    end
  end

  if attributes.key?(:'experiment_id')
    self.experiment_id = attributes[:'experiment_id']
  end

  if attributes.key?(:'revision_frontend_state')
    self.revision_frontend_state = attributes[:'revision_frontend_state']
  end

  if attributes.key?(:'active_revision_id')
    self.active_revision_id = attributes[:'active_revision_id']
  end

  if attributes.key?(:'active_revision_version_id')
    self.active_revision_version_id = attributes[:'active_revision_version_id']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'current_revision_id')
    self.current_revision_id = attributes[:'current_revision_id']
  end

  if attributes.key?(:'current_revision_version_id')
    self.current_revision_version_id = attributes[:'current_revision_version_id']
  end

  if attributes.key?(:'stage_revision')
    self.stage_revision = attributes[:'stage_revision']
  else
    self.stage_revision = false
  end
end

Instance Attribute Details

#active_revision_idObject

ID of the revision that was last activated on this campaign.



157
158
159
# File 'lib/talon_one/models/campaign.rb', line 157

def active_revision_id
  @active_revision_id
end

#active_revision_version_idObject

ID of the revision version that is active on the campaign.



160
161
162
# File 'lib/talon_one/models/campaign.rb', line 160

def active_revision_version_id
  @active_revision_version_id
end

#active_ruleset_idObject

[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.



48
49
50
# File 'lib/talon_one/models/campaign.rb', line 48

def active_ruleset_id
  @active_ruleset_id
end

#add_free_item_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of times the [add free item effect](docs.talon.one/docs/dev/integration-api/api-effects#addfreeitem) can be triggered in this campaign.



103
104
105
# File 'lib/talon_one/models/campaign.rb', line 103

def add_free_item_effect_count
  @add_free_item_effect_count
end

#application_idObject

The ID of the Application that owns this entity.



24
25
26
# File 'lib/talon_one/models/campaign.rb', line 24

def application_id
  @application_id
end

#attributesObject

Arbitrary properties associated with this campaign.



42
43
44
# File 'lib/talon_one/models/campaign.rb', line 42

def attributes
  @attributes
end

#awarded_giveaways_countObject

This property is deprecated. The count should be available under budgets property. Total number of giveaways awarded by rules in this campaign.



106
107
108
# File 'lib/talon_one/models/campaign.rb', line 106

def awarded_giveaways_count
  @awarded_giveaways_count
end

#budgetsObject

A list of all the budgets that are defined by this campaign and their usage. Note: Budgets that are not defined do not appear in this list and their usage is not counted until they are defined.



79
80
81
# File 'lib/talon_one/models/campaign.rb', line 79

def budgets
  @budgets
end

#call_api_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of webhooks triggered by rules in this campaign.



121
122
123
# File 'lib/talon_one/models/campaign.rb', line 121

def call_api_effect_count
  @call_api_effect_count
end

#campaign_groupsObject

The IDs of the [campaign groups](docs.talon.one/docs/product/account/managing-campaign-groups) this campaign belongs to.



67
68
69
# File 'lib/talon_one/models/campaign.rb', line 67

def campaign_groups
  @campaign_groups
end

#coupon_attributesObject

Arbitrary properties associated with coupons in this campaign.



76
77
78
# File 'lib/talon_one/models/campaign.rb', line 76

def coupon_attributes
  @coupon_attributes
end

#coupon_creation_countObject

This property is deprecated. The count should be available under budgets property. Total number of coupons created by rules in this campaign.



94
95
96
# File 'lib/talon_one/models/campaign.rb', line 94

def coupon_creation_count
  @coupon_creation_count
end

#coupon_redemption_countObject

This property is deprecated. The count should be available under budgets property. Number of coupons redeemed in the campaign.



82
83
84
# File 'lib/talon_one/models/campaign.rb', line 82

def coupon_redemption_count
  @coupon_redemption_count
end

#coupon_settingsObject

Returns the value of attribute coupon_settings.



59
60
61
# File 'lib/talon_one/models/campaign.rb', line 59

def coupon_settings
  @coupon_settings
end

#createdObject

The exact moment this entity was created.



21
22
23
# File 'lib/talon_one/models/campaign.rb', line 21

def created
  @created
end

#created_byObject

Name of the user who created this campaign if available.



133
134
135
# File 'lib/talon_one/models/campaign.rb', line 133

def created_by
  @created_by
end

#created_loyalty_points_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty points created by rules in this campaign.



109
110
111
# File 'lib/talon_one/models/campaign.rb', line 109

def created_loyalty_points_count
  @created_loyalty_points_count
end

#created_loyalty_points_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty point creation effects triggered by rules in this campaign.



112
113
114
# File 'lib/talon_one/models/campaign.rb', line 112

def created_loyalty_points_effect_count
  @created_loyalty_points_effect_count
end

#current_revision_idObject

ID of the revision currently being modified for the campaign.



166
167
168
# File 'lib/talon_one/models/campaign.rb', line 166

def current_revision_id
  @current_revision_id
end

#current_revision_version_idObject

ID of the latest version applied on the current revision.



169
170
171
# File 'lib/talon_one/models/campaign.rb', line 169

def current_revision_version_id
  @current_revision_version_id
end

#custom_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of custom effects triggered by rules in this campaign.



97
98
99
# File 'lib/talon_one/models/campaign.rb', line 97

def custom_effect_count
  @custom_effect_count
end

#descriptionObject

A detailed description of the campaign.



33
34
35
# File 'lib/talon_one/models/campaign.rb', line 33

def description
  @description
end

#discount_countObject

This property is deprecated. The count should be available under budgets property. Total amount of discounts redeemed in the campaign.



88
89
90
# File 'lib/talon_one/models/campaign.rb', line 88

def discount_count
  @discount_count
end

#discount_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of times discounts were redeemed in this campaign.



91
92
93
# File 'lib/talon_one/models/campaign.rb', line 91

def discount_effect_count
  @discount_effect_count
end

#end_timeObject

Timestamp when the campaign will become inactive.



39
40
41
# File 'lib/talon_one/models/campaign.rb', line 39

def end_time
  @end_time
end

#experiment_idObject

The ID of the Experiment this Campaign is part of.



151
152
153
# File 'lib/talon_one/models/campaign.rb', line 151

def experiment_id
  @experiment_id
end

#featuresObject

The features enabled in this campaign.



57
58
59
# File 'lib/talon_one/models/campaign.rb', line 57

def features
  @features
end

#frontend_stateObject

The campaign state displayed in the Campaign Manager.



142
143
144
# File 'lib/talon_one/models/campaign.rb', line 142

def frontend_state
  @frontend_state
end

#idObject

Unique ID for this entity.



18
19
20
# File 'lib/talon_one/models/campaign.rb', line 18

def id
  @id
end

#last_activityObject

Timestamp of the most recent event received by this campaign.



127
128
129
# File 'lib/talon_one/models/campaign.rb', line 127

def last_activity
  @last_activity
end

#limitsObject

The set of [budget limits](docs.talon.one/docs/product/campaigns/settings/managing-campaign-budgets) for this campaign.



64
65
66
# File 'lib/talon_one/models/campaign.rb', line 64

def limits
  @limits
end

#linked_store_idsObject

A list of store IDs that you want to link to the campaign. Note: Campaigns with linked store IDs will only be evaluated when there is a [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) that references a linked store.



73
74
75
# File 'lib/talon_one/models/campaign.rb', line 73

def linked_store_ids
  @linked_store_ids
end

#nameObject

A user-facing name for this campaign.



30
31
32
# File 'lib/talon_one/models/campaign.rb', line 30

def name
  @name
end

#redeemed_loyalty_points_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty points redeemed by rules in this campaign.



115
116
117
# File 'lib/talon_one/models/campaign.rb', line 115

def redeemed_loyalty_points_count
  @redeemed_loyalty_points_count
end

#redeemed_loyalty_points_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of loyalty point redemption effects triggered by rules in this campaign.



118
119
120
# File 'lib/talon_one/models/campaign.rb', line 118

def redeemed_loyalty_points_effect_count
  @redeemed_loyalty_points_effect_count
end

#reevaluate_on_returnObject

Indicates whether this campaign should be reevaluated when a customer returns an item.



54
55
56
# File 'lib/talon_one/models/campaign.rb', line 54

def reevaluate_on_return
  @reevaluate_on_return
end

#referral_creation_countObject

This property is deprecated. The count should be available under budgets property. Total number of referrals created by rules in this campaign.



100
101
102
# File 'lib/talon_one/models/campaign.rb', line 100

def referral_creation_count
  @referral_creation_count
end

#referral_redemption_countObject

This property is deprecated. The count should be available under budgets property. Number of referral codes redeemed in the campaign.



85
86
87
# File 'lib/talon_one/models/campaign.rb', line 85

def referral_redemption_count
  @referral_redemption_count
end

#referral_settingsObject

Returns the value of attribute referral_settings.



61
62
63
# File 'lib/talon_one/models/campaign.rb', line 61

def referral_settings
  @referral_settings
end

#reservecoupon_effect_countObject

This property is deprecated. The count should be available under budgets property. Total number of reserve coupon effects triggered by rules in this campaign.



124
125
126
# File 'lib/talon_one/models/campaign.rb', line 124

def reservecoupon_effect_count
  @reservecoupon_effect_count
end

#revision_frontend_stateObject

The campaign revision state displayed in the Campaign Manager.



154
155
156
# File 'lib/talon_one/models/campaign.rb', line 154

def revision_frontend_state
  @revision_frontend_state
end

#stage_revisionObject

Flag for determining whether we use current revision when sending requests with staging API key.



172
173
174
# File 'lib/talon_one/models/campaign.rb', line 172

def stage_revision
  @stage_revision
end

#start_timeObject

Timestamp when the campaign will become active.



36
37
38
# File 'lib/talon_one/models/campaign.rb', line 36

def start_time
  @start_time
end

#stateObject

A disabled or archived campaign is not evaluated for rules or coupons.



45
46
47
# File 'lib/talon_one/models/campaign.rb', line 45

def state
  @state
end

#stores_importedObject

Indicates whether the linked stores were imported via a CSV file.



145
146
147
# File 'lib/talon_one/models/campaign.rb', line 145

def stores_imported
  @stores_imported
end

#tagsObject

A list of tags for the campaign.



51
52
53
# File 'lib/talon_one/models/campaign.rb', line 51

def tags
  @tags
end

#template_idObject

The ID of the Campaign Template this Campaign was created from.



139
140
141
# File 'lib/talon_one/models/campaign.rb', line 139

def template_id
  @template_id
end

#typeObject

The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.



70
71
72
# File 'lib/talon_one/models/campaign.rb', line 70

def type
  @type
end

#updatedObject

Timestamp of the most recent update to the campaign’s property. Updates to external entities used in this campaign are not registered by this property, such as collection or coupon updates.



130
131
132
# File 'lib/talon_one/models/campaign.rb', line 130

def updated
  @updated
end

#updated_byObject

Name of the user who last updated this campaign if available.



136
137
138
# File 'lib/talon_one/models/campaign.rb', line 136

def updated_by
  @updated_by
end

#user_idObject

The ID of the user associated with this entity.



27
28
29
# File 'lib/talon_one/models/campaign.rb', line 27

def user_id
  @user_id
end

#value_maps_idsObject

A list of value map IDs for the campaign.



148
149
150
# File 'lib/talon_one/models/campaign.rb', line 148

def value_maps_ids
  @value_maps_ids
end

#versionObject

Incrementing number representing how many revisions have been activated on this campaign, starts from 0 for a new campaign.



163
164
165
# File 'lib/talon_one/models/campaign.rb', line 163

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/talon_one/models/campaign.rb', line 197

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'application_id' => :'applicationId',
    :'user_id' => :'userId',
    :'name' => :'name',
    :'description' => :'description',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'attributes' => :'attributes',
    :'state' => :'state',
    :'active_ruleset_id' => :'activeRulesetId',
    :'tags' => :'tags',
    :'reevaluate_on_return' => :'reevaluateOnReturn',
    :'features' => :'features',
    :'coupon_settings' => :'couponSettings',
    :'referral_settings' => :'referralSettings',
    :'limits' => :'limits',
    :'campaign_groups' => :'campaignGroups',
    :'type' => :'type',
    :'linked_store_ids' => :'linkedStoreIds',
    :'coupon_attributes' => :'couponAttributes',
    :'budgets' => :'budgets',
    :'coupon_redemption_count' => :'couponRedemptionCount',
    :'referral_redemption_count' => :'referralRedemptionCount',
    :'discount_count' => :'discountCount',
    :'discount_effect_count' => :'discountEffectCount',
    :'coupon_creation_count' => :'couponCreationCount',
    :'custom_effect_count' => :'customEffectCount',
    :'referral_creation_count' => :'referralCreationCount',
    :'add_free_item_effect_count' => :'addFreeItemEffectCount',
    :'awarded_giveaways_count' => :'awardedGiveawaysCount',
    :'created_loyalty_points_count' => :'createdLoyaltyPointsCount',
    :'created_loyalty_points_effect_count' => :'createdLoyaltyPointsEffectCount',
    :'redeemed_loyalty_points_count' => :'redeemedLoyaltyPointsCount',
    :'redeemed_loyalty_points_effect_count' => :'redeemedLoyaltyPointsEffectCount',
    :'call_api_effect_count' => :'callApiEffectCount',
    :'reservecoupon_effect_count' => :'reservecouponEffectCount',
    :'last_activity' => :'lastActivity',
    :'updated' => :'updated',
    :'created_by' => :'createdBy',
    :'updated_by' => :'updatedBy',
    :'template_id' => :'templateId',
    :'frontend_state' => :'frontendState',
    :'stores_imported' => :'storesImported',
    :'value_maps_ids' => :'valueMapsIds',
    :'experiment_id' => :'experimentId',
    :'revision_frontend_state' => :'revisionFrontendState',
    :'active_revision_id' => :'activeRevisionId',
    :'active_revision_version_id' => :'activeRevisionVersionId',
    :'version' => :'version',
    :'current_revision_id' => :'currentRevisionId',
    :'current_revision_version_id' => :'currentRevisionVersionId',
    :'stage_revision' => :'stageRevision'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



793
794
795
# File 'lib/talon_one/models/campaign.rb', line 793

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



315
316
317
318
# File 'lib/talon_one/models/campaign.rb', line 315

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/talon_one/models/campaign.rb', line 256

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'DateTime',
    :'application_id' => :'Integer',
    :'user_id' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'start_time' => :'DateTime',
    :'end_time' => :'DateTime',
    :'attributes' => :'Object',
    :'state' => :'String',
    :'active_ruleset_id' => :'Integer',
    :'tags' => :'Array<String>',
    :'reevaluate_on_return' => :'Boolean',
    :'features' => :'Array<String>',
    :'coupon_settings' => :'CodeGeneratorSettings',
    :'referral_settings' => :'CodeGeneratorSettings',
    :'limits' => :'Array<LimitConfig>',
    :'campaign_groups' => :'Array<Integer>',
    :'type' => :'String',
    :'linked_store_ids' => :'Array<Integer>',
    :'coupon_attributes' => :'Object',
    :'budgets' => :'Array<CampaignBudget>',
    :'coupon_redemption_count' => :'Integer',
    :'referral_redemption_count' => :'Integer',
    :'discount_count' => :'Float',
    :'discount_effect_count' => :'Integer',
    :'coupon_creation_count' => :'Integer',
    :'custom_effect_count' => :'Integer',
    :'referral_creation_count' => :'Integer',
    :'add_free_item_effect_count' => :'Integer',
    :'awarded_giveaways_count' => :'Integer',
    :'created_loyalty_points_count' => :'Float',
    :'created_loyalty_points_effect_count' => :'Integer',
    :'redeemed_loyalty_points_count' => :'Float',
    :'redeemed_loyalty_points_effect_count' => :'Integer',
    :'call_api_effect_count' => :'Integer',
    :'reservecoupon_effect_count' => :'Integer',
    :'last_activity' => :'DateTime',
    :'updated' => :'DateTime',
    :'created_by' => :'String',
    :'updated_by' => :'String',
    :'template_id' => :'Integer',
    :'frontend_state' => :'String',
    :'stores_imported' => :'Boolean',
    :'value_maps_ids' => :'Array<Integer>',
    :'experiment_id' => :'Integer',
    :'revision_frontend_state' => :'String',
    :'active_revision_id' => :'Integer',
    :'active_revision_version_id' => :'Integer',
    :'version' => :'Integer',
    :'current_revision_id' => :'Integer',
    :'current_revision_version_id' => :'Integer',
    :'stage_revision' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/talon_one/models/campaign.rb', line 720

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      application_id == o.application_id &&
      user_id == o.user_id &&
      name == o.name &&
      description == o.description &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      attributes == o.attributes &&
      state == o.state &&
      active_ruleset_id == o.active_ruleset_id &&
      tags == o.tags &&
      reevaluate_on_return == o.reevaluate_on_return &&
      features == o.features &&
      coupon_settings == o.coupon_settings &&
      referral_settings == o.referral_settings &&
      limits == o.limits &&
      campaign_groups == o.campaign_groups &&
      type == o.type &&
      linked_store_ids == o.linked_store_ids &&
      coupon_attributes == o.coupon_attributes &&
      budgets == o.budgets &&
      coupon_redemption_count == o.coupon_redemption_count &&
      referral_redemption_count == o.referral_redemption_count &&
      discount_count == o.discount_count &&
      discount_effect_count == o.discount_effect_count &&
      coupon_creation_count == o.coupon_creation_count &&
      custom_effect_count == o.custom_effect_count &&
      referral_creation_count == o.referral_creation_count &&
      add_free_item_effect_count == o.add_free_item_effect_count &&
      awarded_giveaways_count == o.awarded_giveaways_count &&
      created_loyalty_points_count == o.created_loyalty_points_count &&
      created_loyalty_points_effect_count == o.created_loyalty_points_effect_count &&
      redeemed_loyalty_points_count == o.redeemed_loyalty_points_count &&
      redeemed_loyalty_points_effect_count == o.redeemed_loyalty_points_effect_count &&
      call_api_effect_count == o.call_api_effect_count &&
      reservecoupon_effect_count == o.reservecoupon_effect_count &&
      last_activity == o.last_activity &&
      updated == o.updated &&
      created_by == o.created_by &&
      updated_by == o.updated_by &&
      template_id == o.template_id &&
      frontend_state == o.frontend_state &&
      stores_imported == o.stores_imported &&
      value_maps_ids == o.value_maps_ids &&
      experiment_id == o.experiment_id &&
      revision_frontend_state == o.revision_frontend_state &&
      active_revision_id == o.active_revision_id &&
      active_revision_version_id == o.active_revision_version_id &&
      version == o.version &&
      current_revision_id == o.current_revision_id &&
      current_revision_version_id == o.current_revision_version_id &&
      stage_revision == o.stage_revision
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'lib/talon_one/models/campaign.rb', line 821

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



890
891
892
893
894
895
896
897
898
899
900
901
902
# File 'lib/talon_one/models/campaign.rb', line 890

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/talon_one/models/campaign.rb', line 800

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


780
781
782
# File 'lib/talon_one/models/campaign.rb', line 780

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



786
787
788
# File 'lib/talon_one/models/campaign.rb', line 786

def hash
  [id, created, application_id, user_id, name, description, start_time, end_time, attributes, state, active_ruleset_id, tags, reevaluate_on_return, features, coupon_settings, referral_settings, limits, campaign_groups, type, linked_store_ids, coupon_attributes, budgets, coupon_redemption_count, referral_redemption_count, discount_count, discount_effect_count, coupon_creation_count, custom_effect_count, referral_creation_count, add_free_item_effect_count, awarded_giveaways_count, created_loyalty_points_count, created_loyalty_points_effect_count, redeemed_loyalty_points_count, redeemed_loyalty_points_effect_count, call_api_effect_count, reservecoupon_effect_count, last_activity, updated, created_by, updated_by, template_id, frontend_state, stores_imported, value_maps_ids, experiment_id, revision_frontend_state, active_revision_id, active_revision_version_id, version, current_revision_id, current_revision_version_id, stage_revision].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/talon_one/models/campaign.rb', line 570

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @reevaluate_on_return.nil?
    invalid_properties.push('invalid value for "reevaluate_on_return", reevaluate_on_return cannot be nil.')
  end

  if @features.nil?
    invalid_properties.push('invalid value for "features", features cannot be nil.')
  end

  if @limits.nil?
    invalid_properties.push('invalid value for "limits", limits cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @frontend_state.nil?
    invalid_properties.push('invalid value for "frontend_state", frontend_state cannot be nil.')
  end

  if @stores_imported.nil?
    invalid_properties.push('invalid value for "stores_imported", stores_imported cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



866
867
868
# File 'lib/talon_one/models/campaign.rb', line 866

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



872
873
874
875
876
877
878
879
880
881
882
883
884
# File 'lib/talon_one/models/campaign.rb', line 872

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



860
861
862
# File 'lib/talon_one/models/campaign.rb', line 860

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/talon_one/models/campaign.rb', line 637

def valid?
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  return false if @user_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @description.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"])
  return false unless state_validator.valid?(@state)
  return false if @tags.nil?
  return false if @reevaluate_on_return.nil?
  return false if @features.nil?
  return false if @limits.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"])
  return false unless type_validator.valid?(@type)
  return false if @frontend_state.nil?
  frontend_state_validator = EnumAttributeValidator.new('String', ["expired", "scheduled", "running", "disabled", "archived", "staged"])
  return false unless frontend_state_validator.valid?(@frontend_state)
  return false if @stores_imported.nil?
  revision_frontend_state_validator = EnumAttributeValidator.new('String', ["revised", "pending"])
  return false unless revision_frontend_state_validator.valid?(@revision_frontend_state)
  true
end