Class: TalonOne::CardAddedDeductedPointsBalancesNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/card_added_deducted_points_balances_notification.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CardAddedDeductedPointsBalancesNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CardAddedDeductedPointsBalancesNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CardAddedDeductedPointsBalancesNotification`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'card_identifier')
    self.card_identifier = attributes[:'card_identifier']
  end

  if attributes.key?(:'employee_name')
    self.employee_name = attributes[:'employee_name']
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  end

  if attributes.key?(:'notification_type')
    self.notification_type = attributes[:'notification_type']
  end

  if attributes.key?(:'profile_integration_i_ds')
    if (value = attributes[:'profile_integration_i_ds']).is_a?(Array)
      self.profile_integration_i_ds = value
    end
  end

  if attributes.key?(:'session_integration_id')
    self.session_integration_id = attributes[:'session_integration_id']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  end

  if attributes.key?(:'type_of_change')
    self.type_of_change = attributes[:'type_of_change']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'users_per_card_limit')
    self.users_per_card_limit = attributes[:'users_per_card_limit']
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'current_points')
    self.current_points = attributes[:'current_points']
  end
end

Instance Attribute Details

#actionsObject

The list of actions that have been triggered in the loyalty program.



48
49
50
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 48

def actions
  @actions
end

#card_identifierObject

Loyalty card identification number.



18
19
20
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 18

def card_identifier
  @card_identifier
end

#current_pointsObject

The current points balance.



51
52
53
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 51

def current_points
  @current_points
end

#employee_nameObject

The name of the employee who added or deducted points.



21
22
23
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 21

def employee_name
  @employee_name
end

#loyalty_program_idObject

The ID of the loyalty program.



24
25
26
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 24

def loyalty_program_id
  @loyalty_program_id
end

#notification_typeObject

The type of notification.



27
28
29
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 27

def notification_type
  @notification_type
end

#profile_integration_i_dsObject

The integration ID of the customer profile to whom points were added or deducted.



30
31
32
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 30

def profile_integration_i_ds
  @profile_integration_i_ds
end

#session_integration_idObject

The integration ID of the session through which the points were earned or lost.



33
34
35
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 33

def session_integration_id
  @session_integration_id
end

#subledger_idObject

The ID of the subledger within the loyalty program where these points were added or deducted.



36
37
38
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 36

def subledger_id
  @subledger_id
end

#type_of_changeObject

The notification source, that is, it indicates whether the points were added or deducted via one of the following routes: - [The Campaign Manager](/docs/product/getting-started) - [Management API](/management-api#tag/Loyalty) - [Rule Engine](/docs/product/applications/evaluation-order-for-rules-and-filters)



39
40
41
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 39

def type_of_change
  @type_of_change
end

#user_idObject

The ID of the employee who added or deducted points.



42
43
44
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 42

def user_id
  @user_id
end

#users_per_card_limitObject

The max amount of user profiles with whom a card can be shared. This can be set to ‘0` for no limit.



45
46
47
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 45

def users_per_card_limit
  @users_per_card_limit
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 76

def self.attribute_map
  {
    :'card_identifier' => :'CardIdentifier',
    :'employee_name' => :'EmployeeName',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'notification_type' => :'NotificationType',
    :'profile_integration_i_ds' => :'ProfileIntegrationIDs',
    :'session_integration_id' => :'SessionIntegrationID',
    :'subledger_id' => :'SubledgerID',
    :'type_of_change' => :'TypeOfChange',
    :'user_id' => :'UserID',
    :'users_per_card_limit' => :'UsersPerCardLimit',
    :'actions' => :'Actions',
    :'current_points' => :'CurrentPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 335

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 94

def self.openapi_types
  {
    :'card_identifier' => :'String',
    :'employee_name' => :'String',
    :'loyalty_program_id' => :'Integer',
    :'notification_type' => :'String',
    :'profile_integration_i_ds' => :'Array<String>',
    :'session_integration_id' => :'String',
    :'subledger_id' => :'String',
    :'type_of_change' => :'String',
    :'user_id' => :'Integer',
    :'users_per_card_limit' => :'Integer',
    :'actions' => :'Array<AddedDeductedPointsBalancesAction>',
    :'current_points' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 303

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      card_identifier == o.card_identifier &&
      employee_name == o.employee_name &&
      loyalty_program_id == o.loyalty_program_id &&
      notification_type == o.notification_type &&
      profile_integration_i_ds == o.profile_integration_i_ds &&
      session_integration_id == o.session_integration_id &&
      subledger_id == o.subledger_id &&
      type_of_change == o.type_of_change &&
      user_id == o.user_id &&
      users_per_card_limit == o.users_per_card_limit &&
      actions == o.actions &&
      current_points == o.current_points
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 363

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 432

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 342

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 322

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



328
329
330
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 328

def hash
  [card_identifier, employee_name, loyalty_program_id, notification_type, profile_integration_i_ds, session_integration_id, subledger_id, type_of_change, user_id, users_per_card_limit, actions, current_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 187

def list_invalid_properties
  invalid_properties = Array.new
  if @card_identifier.nil?
    invalid_properties.push('invalid value for "card_identifier", card_identifier cannot be nil.')
  end

  if @employee_name.nil?
    invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @loyalty_program_id < 1
    invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.')
  end

  if @notification_type.nil?
    invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.')
  end

  if @profile_integration_i_ds.nil?
    invalid_properties.push('invalid value for "profile_integration_i_ds", profile_integration_i_ds cannot be nil.')
  end

  if @session_integration_id.nil?
    invalid_properties.push('invalid value for "session_integration_id", session_integration_id cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @type_of_change.nil?
    invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @users_per_card_limit.nil?
    invalid_properties.push('invalid value for "users_per_card_limit", users_per_card_limit cannot be nil.')
  end

  if @actions.nil?
    invalid_properties.push('invalid value for "actions", actions cannot be nil.')
  end

  if @current_points.nil?
    invalid_properties.push('invalid value for "current_points", current_points cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 408

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 414

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



402
403
404
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 402

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/talon_one/models/card_added_deducted_points_balances_notification.rb', line 246

def valid?
  return false if @card_identifier.nil?
  return false if @employee_name.nil?
  return false if @loyalty_program_id.nil?
  return false if @loyalty_program_id < 1
  return false if @notification_type.nil?
  notification_type_validator = EnumAttributeValidator.new('String', ["LoyaltyCardAddedDeductedPointsBalances"])
  return false unless notification_type_validator.valid?(@notification_type)
  return false if @profile_integration_i_ds.nil?
  return false if @session_integration_id.nil?
  return false if @subledger_id.nil?
  return false if @type_of_change.nil?
  type_of_change_validator = EnumAttributeValidator.new('String', ["campaign_manager", "rule_engine", "management_api"])
  return false unless type_of_change_validator.valid?(@type_of_change)
  return false if @user_id.nil?
  return false if @users_per_card_limit.nil?
  return false if @actions.nil?
  return false if @current_points.nil?
  true
end