Class: TalonOne::CardLedgerPointsEntryIntegrationAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/card_ledger_points_entry_integration_api.rb

Overview

Loyalty card points with start and expiry dates.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CardLedgerPointsEntryIntegrationAPI

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::CardLedgerPointsEntryIntegrationAPI` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::CardLedgerPointsEntryIntegrationAPI`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'transaction_uuid')
    self.transaction_uuid = attributes[:'transaction_uuid']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'program_id')
    self.program_id = attributes[:'program_id']
  end

  if attributes.key?(:'customer_profile_id')
    self.customer_profile_id = attributes[:'customer_profile_id']
  end

  if attributes.key?(:'customer_session_id')
    self.customer_session_id = attributes[:'customer_session_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'validity_duration')
    self.validity_duration = attributes[:'validity_duration']
  end
end

Instance Attribute Details

#amountObject

Amount of loyalty points added in the transaction.



49
50
51
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 49

def amount
  @amount
end

#createdObject

Date and time the loyalty card points were added.



25
26
27
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 25

def created
  @created
end

#customer_profile_idObject

Integration ID of the customer profile linked to the card.



31
32
33
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 31

def customer_profile_id
  @customer_profile_id
end

#customer_session_idObject

ID of the customer session where points were added.



34
35
36
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 34

def customer_session_id
  @customer_session_id
end

#expiry_dateObject

Date when points expire. Possible values are: - ‘unlimited`: Points have no expiration date. - `timestamp value`: Points expire on the given date and time.



43
44
45
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 43

def expiry_date
  @expiry_date
end

#idObject

ID of the transaction that adds loyalty points.



19
20
21
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 19

def id
  @id
end

#nameObject

Name or reason of the transaction that adds loyalty points.



37
38
39
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 37

def name
  @name
end

#program_idObject

ID of the loyalty program.



28
29
30
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 28

def program_id
  @program_id
end

#start_dateObject

When points become active. Possible values: - ‘immediate`: Points are active immediately. - `timestamp value`: Points become active at a given date and time.



40
41
42
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 40

def start_date
  @start_date
end

#subledger_idObject

ID of the subledger.



46
47
48
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 46

def subledger_id
  @subledger_id
end

#transaction_uuidObject

Unique identifier of the transaction in the UUID format.



22
23
24
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 22

def transaction_uuid
  @transaction_uuid
end

#validity_durationObject

The duration for which the points remain active, relative to the activation date. Note: This only applies to points for which ‘awaitsActivation` is `true` and `expiryDate` is not set.



52
53
54
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 52

def validity_duration
  @validity_duration
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'transaction_uuid' => :'transactionUUID',
    :'created' => :'created',
    :'program_id' => :'programId',
    :'customer_profile_id' => :'customerProfileID',
    :'customer_session_id' => :'customerSessionId',
    :'name' => :'name',
    :'start_date' => :'startDate',
    :'expiry_date' => :'expiryDate',
    :'subledger_id' => :'subledgerId',
    :'amount' => :'amount',
    :'validity_duration' => :'validityDuration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



324
325
326
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 324

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 73

def self.openapi_types
  {
    :'id' => :'Integer',
    :'transaction_uuid' => :'String',
    :'created' => :'DateTime',
    :'program_id' => :'Integer',
    :'customer_profile_id' => :'String',
    :'customer_session_id' => :'String',
    :'name' => :'String',
    :'start_date' => :'String',
    :'expiry_date' => :'String',
    :'subledger_id' => :'String',
    :'amount' => :'Float',
    :'validity_duration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      transaction_uuid == o.transaction_uuid &&
      created == o.created &&
      program_id == o.program_id &&
      customer_profile_id == o.customer_profile_id &&
      customer_session_id == o.customer_session_id &&
      name == o.name &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      subledger_id == o.subledger_id &&
      amount == o.amount &&
      validity_duration == o.validity_duration
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 352

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 421

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 331

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


311
312
313
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 311

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



317
318
319
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 317

def hash
  [id, transaction_uuid, created, program_id, customer_profile_id, customer_session_id, name, start_date, expiry_date, subledger_id, amount, validity_duration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 162

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @transaction_uuid.nil?
    invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @program_id.nil?
    invalid_properties.push('invalid value for "program_id", program_id cannot be nil.')
  end

  if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
    invalid_properties.push('invalid value for "customer_session_id", the character length must be smaller than or equal to 255.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @start_date.to_s.length > 64
    invalid_properties.push('invalid value for "start_date", the character length must be smaller than or equal to 64.')
  end

  if @expiry_date.nil?
    invalid_properties.push('invalid value for "expiry_date", expiry_date cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @subledger_id.to_s.length > 64
    invalid_properties.push('invalid value for "subledger_id", the character length must be smaller than or equal to 64.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 397

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 403

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



391
392
393
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 391

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/talon_one/models/card_ledger_points_entry_integration_api.rb', line 221

def valid?
  return false if @id.nil?
  return false if @transaction_uuid.nil?
  return false if @created.nil?
  return false if @program_id.nil?
  return false if !@customer_session_id.nil? && @customer_session_id.to_s.length > 255
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @start_date.nil?
  return false if @start_date.to_s.length > 64
  return false if @expiry_date.nil?
  return false if @subledger_id.nil?
  return false if @subledger_id.to_s.length > 64
  return false if @amount.nil?
  true
end