Class: TalonOne::DeleteCouponsData
- Inherits:
-
Object
- Object
- TalonOne::DeleteCouponsData
- Defined in:
- lib/talon_one/models/delete_coupons_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#batch_id ⇒ Object
Returns the value of attribute batch_id.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#employee_name ⇒ Object
Returns the value of attribute employee_name.
-
#notification_type ⇒ Object
The type of the notification.
-
#operation ⇒ Object
Returns the value of attribute operation.
-
#total_result_size ⇒ Object
Returns the value of attribute total_result_size.
-
#type_of_change ⇒ Object
Returns the value of attribute type_of_change.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeleteCouponsData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DeleteCouponsData
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::DeleteCouponsData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::DeleteCouponsData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type_of_change') self.type_of_change = attributes[:'type_of_change'] end if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'employee_name') self.employee_name = attributes[:'employee_name'] end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'total_result_size') self.total_result_size = attributes[:'total_result_size'] end if attributes.key?(:'notification_type') self.notification_type = attributes[:'notification_type'] end end |
Instance Attribute Details
#application_id ⇒ Object
Returns the value of attribute application_id.
25 26 27 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 25 def application_id @application_id end |
#batch_id ⇒ Object
Returns the value of attribute batch_id.
23 24 25 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 23 def batch_id @batch_id end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
27 28 29 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 27 def campaign_id @campaign_id end |
#employee_name ⇒ Object
Returns the value of attribute employee_name.
21 22 23 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 21 def employee_name @employee_name end |
#notification_type ⇒ Object
The type of the notification
32 33 34 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 32 def notification_type @notification_type end |
#operation ⇒ Object
Returns the value of attribute operation.
19 20 21 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 19 def operation @operation end |
#total_result_size ⇒ Object
Returns the value of attribute total_result_size.
29 30 31 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 29 def total_result_size @total_result_size end |
#type_of_change ⇒ Object
Returns the value of attribute type_of_change.
17 18 19 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 17 def type_of_change @type_of_change end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 57 def self.attribute_map { :'type_of_change' => :'TypeOfChange', :'operation' => :'Operation', :'employee_name' => :'EmployeeName', :'batch_id' => :'BatchID', :'application_id' => :'ApplicationID', :'campaign_id' => :'CampaignID', :'total_result_size' => :'TotalResultSize', :'notification_type' => :'NotificationType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 233 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 71 def self.openapi_types { :'type_of_change' => :'String', :'operation' => :'String', :'employee_name' => :'String', :'batch_id' => :'String', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'total_result_size' => :'Integer', :'notification_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 205 def ==(o) return true if self.equal?(o) self.class == o.class && type_of_change == o.type_of_change && operation == o.operation && employee_name == o.employee_name && batch_id == o.batch_id && application_id == o.application_id && campaign_id == o.campaign_id && total_result_size == o.total_result_size && notification_type == o.notification_type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 261 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 330 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 226 def hash [type_of_change, operation, employee_name, batch_id, application_id, campaign_id, total_result_size, notification_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 140 def list_invalid_properties invalid_properties = Array.new if @type_of_change.nil? invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.') end if @operation.nil? invalid_properties.push('invalid value for "operation", operation cannot be nil.') end if @employee_name.nil? invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.') end if @batch_id.nil? invalid_properties.push('invalid value for "batch_id", batch_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @total_result_size.nil? invalid_properties.push('invalid value for "total_result_size", total_result_size cannot be nil.') end if @notification_type.nil? invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
306 307 308 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 306 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 300 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/talon_one/models/delete_coupons_data.rb', line 179 def valid? return false if @type_of_change.nil? return false if @operation.nil? return false if @employee_name.nil? return false if @batch_id.nil? return false if @application_id.nil? return false if @campaign_id.nil? return false if @total_result_size.nil? return false if @notification_type.nil? notification_type_validator = EnumAttributeValidator.new('String', ["CouponsDeleted"]) return false unless notification_type_validator.valid?(@notification_type) true end |