Class: TalonOne::EventV3

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/event_v3.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EventV3

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/talon_one/models/event_v3.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::EventV3` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::EventV3`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'store_integration_id')
    self.store_integration_id = attributes[:'store_integration_id']
  end

  if attributes.key?(:'evaluable_campaign_ids')
    if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array)
      self.evaluable_campaign_ids = value
    end
  end

  if attributes.key?(:'integration_id')
    self.integration_id = attributes[:'integration_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'connected_session_id')
    self.connected_session_id = attributes[:'connected_session_id']
  end

  if attributes.key?(:'previous_event_id')
    self.previous_event_id = attributes[:'previous_event_id']
  end
end

Instance Attribute Details

#attributesObject

Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).



33
34
35
# File 'lib/talon_one/models/event_v3.rb', line 33

def attributes
  @attributes
end

#connected_session_idObject

The ID of the session that happened in the past.



36
37
38
# File 'lib/talon_one/models/event_v3.rb', line 36

def connected_session_id
  @connected_session_id
end

#evaluable_campaign_idsObject

When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.



24
25
26
# File 'lib/talon_one/models/event_v3.rb', line 24

def evaluable_campaign_ids
  @evaluable_campaign_ids
end

#integration_idObject

The unique ID of the current event. Only one event with this ID could be activated, duplicated events are forbidden.



27
28
29
# File 'lib/talon_one/models/event_v3.rb', line 27

def integration_id
  @integration_id
end

#previous_event_idObject

The unique identifier of the event that happened in the past.



39
40
41
# File 'lib/talon_one/models/event_v3.rb', line 39

def previous_event_id
  @previous_event_id
end

#profile_idObject

ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.



18
19
20
# File 'lib/talon_one/models/event_v3.rb', line 18

def profile_id
  @profile_id
end

#store_integration_idObject

The integration ID of the store. You choose this ID when you create a store.



21
22
23
# File 'lib/talon_one/models/event_v3.rb', line 21

def store_integration_id
  @store_integration_id
end

#typeObject

A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.



30
31
32
# File 'lib/talon_one/models/event_v3.rb', line 30

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/talon_one/models/event_v3.rb', line 42

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'store_integration_id' => :'storeIntegrationId',
    :'evaluable_campaign_ids' => :'evaluableCampaignIds',
    :'integration_id' => :'integrationId',
    :'type' => :'type',
    :'attributes' => :'attributes',
    :'connected_session_id' => :'connectedSessionID',
    :'previous_event_id' => :'previousEventID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
# File 'lib/talon_one/models/event_v3.rb', line 275

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/talon_one/models/event_v3.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/talon_one/models/event_v3.rb', line 56

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'store_integration_id' => :'String',
    :'evaluable_campaign_ids' => :'Array<Integer>',
    :'integration_id' => :'String',
    :'type' => :'String',
    :'attributes' => :'Object',
    :'connected_session_id' => :'String',
    :'previous_event_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/talon_one/models/event_v3.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      store_integration_id == o.store_integration_id &&
      evaluable_campaign_ids == o.evaluable_campaign_ids &&
      integration_id == o.integration_id &&
      type == o.type &&
      attributes == o.attributes &&
      connected_session_id == o.connected_session_id &&
      previous_event_id == o.previous_event_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/talon_one/models/event_v3.rb', line 303

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/talon_one/models/event_v3.rb', line 372

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/talon_one/models/event_v3.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/talon_one/models/event_v3.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/talon_one/models/event_v3.rb', line 268

def hash
  [profile_id, store_integration_id, evaluable_campaign_ids, integration_id, type, attributes, connected_session_id, previous_event_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/talon_one/models/event_v3.rb', line 127

def list_invalid_properties
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
    invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.')
  end

  if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "store_integration_id", the character length must be great than or equal to 1.')
  end

  if @integration_id.nil?
    invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.')
  end

  if @integration_id.to_s.length < 1
    invalid_properties.push('invalid value for "integration_id", the character length must be great than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @type.to_s.length < 1
    invalid_properties.push('invalid value for "type", the character length must be great than or equal to 1.')
  end

  if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
    invalid_properties.push('invalid value for "connected_session_id", the character length must be great than or equal to 1.')
  end

  if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1
    invalid_properties.push('invalid value for "previous_event_id", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
# File 'lib/talon_one/models/event_v3.rb', line 348

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/talon_one/models/event_v3.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



342
343
344
# File 'lib/talon_one/models/event_v3.rb', line 342

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/talon_one/models/event_v3.rb', line 170

def valid?
  return false if @profile_id.nil?
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000
  return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1
  return false if @integration_id.nil?
  return false if @integration_id.to_s.length < 1
  return false if @type.nil?
  return false if @type.to_s.length < 1
  return false if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1
  return false if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1
  true
end