Class: TalonOne::Experiment

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/experiment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Experiment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/talon_one/models/experiment.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Experiment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Experiment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'is_variant_assignment_external')
    self.is_variant_assignment_external = attributes[:'is_variant_assignment_external']
  end

  if attributes.key?(:'campaign')
    self.campaign = attributes[:'campaign']
  end

  if attributes.key?(:'activated')
    self.activated = attributes[:'activated']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'disabled'
  end

  if attributes.key?(:'variants')
    if (value = attributes[:'variants']).is_a?(Array)
      self.variants = value
    end
  end

  if attributes.key?(:'deletedat')
    self.deletedat = attributes[:'deletedat']
  end
end

Instance Attribute Details

#activatedObject

The date and time the experiment was activated.



32
33
34
# File 'lib/talon_one/models/experiment.rb', line 32

def activated
  @activated
end

#application_idObject

The ID of the Application that owns this entity.



24
25
26
# File 'lib/talon_one/models/experiment.rb', line 24

def application_id
  @application_id
end

#campaignObject

Returns the value of attribute campaign.



29
30
31
# File 'lib/talon_one/models/experiment.rb', line 29

def campaign
  @campaign
end

#createdObject

The time this entity was created.



21
22
23
# File 'lib/talon_one/models/experiment.rb', line 21

def created
  @created
end

#deletedatObject

The date and time the experiment was deleted.



40
41
42
# File 'lib/talon_one/models/experiment.rb', line 40

def deletedat
  @deletedat
end

#idObject

The internal ID of this entity.



18
19
20
# File 'lib/talon_one/models/experiment.rb', line 18

def id
  @id
end

#is_variant_assignment_externalObject

The source of the assignment. - false - The variant assignment is handled internally by Talon.One. - true - The variant assignment is handled externally.



27
28
29
# File 'lib/talon_one/models/experiment.rb', line 27

def is_variant_assignment_external
  @is_variant_assignment_external
end

#stateObject

A disabled experiment is not evaluated for rules or coupons.



35
36
37
# File 'lib/talon_one/models/experiment.rb', line 35

def state
  @state
end

#variantsObject

Returns the value of attribute variants.



37
38
39
# File 'lib/talon_one/models/experiment.rb', line 37

def variants
  @variants
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/talon_one/models/experiment.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'application_id' => :'applicationId',
    :'is_variant_assignment_external' => :'isVariantAssignmentExternal',
    :'campaign' => :'campaign',
    :'activated' => :'activated',
    :'state' => :'state',
    :'variants' => :'variants',
    :'deletedat' => :'deletedat'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
# File 'lib/talon_one/models/experiment.rb', line 232

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/talon_one/models/experiment.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/talon_one/models/experiment.rb', line 80

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'DateTime',
    :'application_id' => :'Integer',
    :'is_variant_assignment_external' => :'Boolean',
    :'campaign' => :'Campaign',
    :'activated' => :'DateTime',
    :'state' => :'String',
    :'variants' => :'Array<ExperimentVariant>',
    :'deletedat' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/talon_one/models/experiment.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      application_id == o.application_id &&
      is_variant_assignment_external == o.is_variant_assignment_external &&
      campaign == o.campaign &&
      activated == o.activated &&
      state == o.state &&
      variants == o.variants &&
      deletedat == o.deletedat
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/talon_one/models/experiment.rb', line 260

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/talon_one/models/experiment.rb', line 329

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/talon_one/models/experiment.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/talon_one/models/experiment.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/talon_one/models/experiment.rb', line 225

def hash
  [id, created, application_id, is_variant_assignment_external, campaign, activated, state, variants, deletedat].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/talon_one/models/experiment.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
# File 'lib/talon_one/models/experiment.rb', line 305

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/talon_one/models/experiment.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



299
300
301
# File 'lib/talon_one/models/experiment.rb', line 299

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
# File 'lib/talon_one/models/experiment.rb', line 181

def valid?
  return false if @id.nil?
  return false if @created.nil?
  return false if @application_id.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"])
  return false unless state_validator.valid?(@state)
  true
end