Class: TalonOne::ExperimentSegmentInsights
- Inherits:
-
Object
- Object
- TalonOne::ExperimentSegmentInsights
- Defined in:
- lib/talon_one/models/experiment_segment_insights.rb
Instance Attribute Summary collapse
-
#dimensions_tested ⇒ Object
Number of segmentation dimensions that had sufficient data variance to test.
-
#metrics ⇒ Object
Segment insights grouped by metric.
-
#reason ⇒ Object
Empty string when segment insights are available.
-
#total_segments_tested ⇒ Object
Total number of segment-metric combinations that were tested for statistical significance.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExperimentSegmentInsights
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ExperimentSegmentInsights
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::ExperimentSegmentInsights` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::ExperimentSegmentInsights`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'metrics') if (value = attributes[:'metrics']).is_a?(Array) self.metrics = value end end if attributes.key?(:'total_segments_tested') self.total_segments_tested = attributes[:'total_segments_tested'] end if attributes.key?(:'dimensions_tested') self.dimensions_tested = attributes[:'dimensions_tested'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end end |
Instance Attribute Details
#dimensions_tested ⇒ Object
Number of segmentation dimensions that had sufficient data variance to test. Dimensions where all sessions fall into a single bucket are excluded.
24 25 26 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 24 def dimensions_tested @dimensions_tested end |
#metrics ⇒ Object
Segment insights grouped by metric. This array always contains exactly three metric objects. Each metric includes a segments array, which is empty if no significant results were found. The metrics array itself is empty if the ‘reason` property is populated.
18 19 20 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 18 def metrics @metrics end |
#reason ⇒ Object
Empty string when segment insights are available. Contains a reason code when insights could not be computed (e.g., "insufficient_data" when the experiment has fewer than 100 sessions per variant).
27 28 29 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 27 def reason @reason end |
#total_segments_tested ⇒ Object
Total number of segment-metric combinations that were tested for statistical significance.
21 22 23 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 21 def total_segments_tested @total_segments_tested end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 30 def self.attribute_map { :'metrics' => :'metrics', :'total_segments_tested' => :'totalSegmentsTested', :'dimensions_tested' => :'dimensionsTested', :'reason' => :'reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 148 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 40 def self.openapi_types { :'metrics' => :'Array<ExperimentSegmentInsightMetric>', :'total_segments_tested' => :'Integer', :'dimensions_tested' => :'Integer', :'reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && metrics == o.metrics && total_segments_tested == o.total_segments_tested && dimensions_tested == o.dimensions_tested && reason == o.reason end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 176 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 245 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 141 def hash [metrics, total_segments_tested, dimensions_tested, reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 91 def list_invalid_properties invalid_properties = Array.new if @metrics.nil? invalid_properties.push('invalid value for "metrics", metrics cannot be nil.') end if @total_segments_tested.nil? invalid_properties.push('invalid value for "total_segments_tested", total_segments_tested cannot be nil.') end if @dimensions_tested.nil? invalid_properties.push('invalid value for "dimensions_tested", dimensions_tested cannot be nil.') end if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
221 222 223 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 221 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 215 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 120 |
# File 'lib/talon_one/models/experiment_segment_insights.rb', line 114 def valid? return false if @metrics.nil? return false if @total_segments_tested.nil? return false if @dimensions_tested.nil? return false if @reason.nil? true end |