Class: TalonOne::IntegrationEventV2Response
- Inherits:
-
Object
- Object
- TalonOne::IntegrationEventV2Response
- Defined in:
- lib/talon_one/models/integration_event_v2_response.rb
Overview
This is the response type returned by the trackEventV2 endpoint.
Instance Attribute Summary collapse
-
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
-
#created_coupons ⇒ Object
The coupons that were created during the event processing.
-
#created_referrals ⇒ Object
The referrals that were created during the event processing.
-
#customer_profile ⇒ Object
Returns the value of attribute customer_profile.
-
#effects ⇒ Object
The effects generated by the rules in your running campaigns.
-
#event ⇒ Object
Returns the value of attribute event.
-
#loyalty ⇒ Object
Returns the value of attribute loyalty.
-
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
-
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationEventV2Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationEventV2Response
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationEventV2Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationEventV2Response`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_profile') self.customer_profile = attributes[:'customer_profile'] end if attributes.key?(:'loyalty') self.loyalty = attributes[:'loyalty'] end if attributes.key?(:'triggered_campaigns') if (value = attributes[:'triggered_campaigns']).is_a?(Array) self.triggered_campaigns = value end end if attributes.key?(:'effects') if (value = attributes[:'effects']).is_a?(Array) self.effects = value end end if attributes.key?(:'rule_failure_reasons') if (value = attributes[:'rule_failure_reasons']).is_a?(Array) self.rule_failure_reasons = value end end if attributes.key?(:'created_coupons') if (value = attributes[:'created_coupons']).is_a?(Array) self.created_coupons = value end end if attributes.key?(:'created_referrals') if (value = attributes[:'created_referrals']).is_a?(Array) self.created_referrals = value end end if attributes.key?(:'awarded_giveaways') if (value = attributes[:'awarded_giveaways']).is_a?(Array) self.awarded_giveaways = value end end if attributes.key?(:'event') self.event = attributes[:'event'] end end |
Instance Attribute Details
#awarded_giveaways ⇒ Object
The giveaways that were awarded during the event processing.
38 39 40 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 38 def awarded_giveaways @awarded_giveaways end |
#created_coupons ⇒ Object
The coupons that were created during the event processing.
32 33 34 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 32 def created_coupons @created_coupons end |
#created_referrals ⇒ Object
The referrals that were created during the event processing.
35 36 37 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 35 def created_referrals @created_referrals end |
#customer_profile ⇒ Object
Returns the value of attribute customer_profile.
18 19 20 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 18 def customer_profile @customer_profile end |
#effects ⇒ Object
The effects generated by the rules in your running campaigns. See [API effects](docs.talon.one/docs/dev/integration-api/api-effects).
26 27 28 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 26 def effects @effects end |
#event ⇒ Object
Returns the value of attribute event.
40 41 42 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 40 def event @event end |
#loyalty ⇒ Object
Returns the value of attribute loyalty.
20 21 22 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 20 def loyalty @loyalty end |
#rule_failure_reasons ⇒ Object
The reasons why certain rules were not triggered during the event processing.
29 30 31 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 29 def rule_failure_reasons @rule_failure_reasons end |
#triggered_campaigns ⇒ Object
The campaigns that were triggered as a result of processing the event.
23 24 25 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 23 def triggered_campaigns @triggered_campaigns end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 43 def self.attribute_map { :'customer_profile' => :'customerProfile', :'loyalty' => :'loyalty', :'triggered_campaigns' => :'triggeredCampaigns', :'effects' => :'effects', :'rule_failure_reasons' => :'ruleFailureReasons', :'created_coupons' => :'createdCoupons', :'created_referrals' => :'createdReferrals', :'awarded_giveaways' => :'awardedGiveaways', :'event' => :'event' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 201 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 58 def self.openapi_types { :'customer_profile' => :'CustomerProfile', :'loyalty' => :'Loyalty', :'triggered_campaigns' => :'Array<Campaign>', :'effects' => :'Array<Effect>', :'rule_failure_reasons' => :'Array<RuleFailureReason>', :'created_coupons' => :'Array<Coupon>', :'created_referrals' => :'Array<Referral>', :'awarded_giveaways' => :'Array<Giveaway>', :'event' => :'Event' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && customer_profile == o.customer_profile && loyalty == o.loyalty && triggered_campaigns == o.triggered_campaigns && effects == o.effects && rule_failure_reasons == o.rule_failure_reasons && created_coupons == o.created_coupons && created_referrals == o.created_referrals && awarded_giveaways == o.awarded_giveaways && event == o.event end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 229 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 298 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 208 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 194 def hash [customer_profile, loyalty, triggered_campaigns, effects, rule_failure_reasons, created_coupons, created_referrals, awarded_giveaways, event].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 144 def list_invalid_properties invalid_properties = Array.new if @effects.nil? invalid_properties.push('invalid value for "effects", effects cannot be nil.') end if @created_coupons.nil? invalid_properties.push('invalid value for "created_coupons", created_coupons cannot be nil.') end if @created_referrals.nil? invalid_properties.push('invalid value for "created_referrals", created_referrals cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
274 275 276 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 274 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 268 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 |
# File 'lib/talon_one/models/integration_event_v2_response.rb', line 163 def valid? return false if @effects.nil? return false if @created_coupons.nil? return false if @created_referrals.nil? true end |