Class: TalonOne::IntegrationEventV3Request
- Inherits:
-
Object
- Object
- TalonOne::IntegrationEventV3Request
- Defined in:
- lib/talon_one/models/integration_event_v3_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event.
-
#connected_session_id ⇒ Object
The ID of the session that happened in the past.
-
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine.
-
#integration_id ⇒ Object
The unique ID of the current event.
-
#loyalty_cards ⇒ Object
Identifiers of the loyalty cards used during this event.
-
#previous_event_id ⇒ Object
The unique identifier of the event that happened in the past.
-
#profile_id ⇒ Object
ID of the customer profile set by your integration layer.
-
#response_content ⇒ Object
Optional list of requested information to be present on the response related to the tracking custom event.
-
#store_integration_id ⇒ Object
The integration ID of the store.
-
#type ⇒ Object
A string representing the event name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationEventV3Request
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationEventV3Request
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationEventV3Request` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationEventV3Request`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'store_integration_id') self.store_integration_id = attributes[:'store_integration_id'] end if attributes.key?(:'evaluable_campaign_ids') if (value = attributes[:'evaluable_campaign_ids']).is_a?(Array) self.evaluable_campaign_ids = value end end if attributes.key?(:'integration_id') self.integration_id = attributes[:'integration_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'connected_session_id') self.connected_session_id = attributes[:'connected_session_id'] end if attributes.key?(:'previous_event_id') self.previous_event_id = attributes[:'previous_event_id'] end if attributes.key?(:'loyalty_cards') if (value = attributes[:'loyalty_cards']).is_a?(Array) self.loyalty_cards = value end end if attributes.key?(:'response_content') if (value = attributes[:'response_content']).is_a?(Array) self.response_content = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Arbitrary additional JSON properties associated with the event. They must be created in the Campaign Manager before setting them with this property. See [creating custom attributes](docs.talon.one/docs/product/account/dev-tools/managing-attributes#creating-a-custom-attribute).
33 34 35 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 33 def attributes @attributes end |
#connected_session_id ⇒ Object
The ID of the session that happened in the past.
36 37 38 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 36 def connected_session_id @connected_session_id end |
#evaluable_campaign_ids ⇒ Object
When using the ‘dry` query parameter, use this property to list the campaign to be evaluated by the Rule Engine. These campaigns will be evaluated, even if they are disabled, allowing you to test specific campaigns before activating them.
24 25 26 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 24 def evaluable_campaign_ids @evaluable_campaign_ids end |
#integration_id ⇒ Object
The unique ID of the current event. Only one event with this ID could be activated, duplicated events are forbidden.
27 28 29 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 27 def integration_id @integration_id end |
#loyalty_cards ⇒ Object
Identifiers of the loyalty cards used during this event.
42 43 44 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 42 def loyalty_cards @loyalty_cards end |
#previous_event_id ⇒ Object
The unique identifier of the event that happened in the past.
39 40 41 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 39 def previous_event_id @previous_event_id end |
#profile_id ⇒ Object
ID of the customer profile set by your integration layer. Note: If the customer does not yet have a known ‘profileId`, we recommend you use a guest `profileId`.
18 19 20 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 18 def profile_id @profile_id end |
#response_content ⇒ Object
Optional list of requested information to be present on the response related to the tracking custom event.
45 46 47 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 45 def response_content @response_content end |
#store_integration_id ⇒ Object
The integration ID of the store. You choose this ID when you create a store.
21 22 23 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 21 def store_integration_id @store_integration_id end |
#type ⇒ Object
A string representing the event name. Must not be a reserved event name. You create this value when you [create an attribute](docs.talon.one/docs/dev/concepts/entities/events#creating-a-custom-event) of type ‘event` in the Campaign Manager.
30 31 32 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 30 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 70 def self.attribute_map { :'profile_id' => :'profileId', :'store_integration_id' => :'storeIntegrationId', :'evaluable_campaign_ids' => :'evaluableCampaignIds', :'integration_id' => :'integrationId', :'type' => :'type', :'attributes' => :'attributes', :'connected_session_id' => :'connectedSessionID', :'previous_event_id' => :'previousEventID', :'loyalty_cards' => :'loyaltyCards', :'response_content' => :'responseContent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 321 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 86 def self.openapi_types { :'profile_id' => :'String', :'store_integration_id' => :'String', :'evaluable_campaign_ids' => :'Array<Integer>', :'integration_id' => :'String', :'type' => :'String', :'attributes' => :'Object', :'connected_session_id' => :'String', :'previous_event_id' => :'String', :'loyalty_cards' => :'Array<String>', :'response_content' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && profile_id == o.profile_id && store_integration_id == o.store_integration_id && evaluable_campaign_ids == o.evaluable_campaign_ids && integration_id == o.integration_id && type == o.type && attributes == o.attributes && connected_session_id == o.connected_session_id && previous_event_id == o.previous_event_id && loyalty_cards == o.loyalty_cards && response_content == o.response_content end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 349 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 418 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 328 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
308 309 310 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 308 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 314 def hash [profile_id, store_integration_id, evaluable_campaign_ids, integration_id, type, attributes, connected_session_id, previous_event_id, loyalty_cards, response_content].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 171 def list_invalid_properties invalid_properties = Array.new if @profile_id.nil? invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 invalid_properties.push('invalid value for "store_integration_id", the character length must be smaller than or equal to 1000.') end if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 invalid_properties.push('invalid value for "store_integration_id", the character length must be great than or equal to 1.') end if @integration_id.nil? invalid_properties.push('invalid value for "integration_id", integration_id cannot be nil.') end if @integration_id.to_s.length < 1 invalid_properties.push('invalid value for "integration_id", the character length must be great than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length < 1 invalid_properties.push('invalid value for "type", the character length must be great than or equal to 1.') end if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1 invalid_properties.push('invalid value for "connected_session_id", the character length must be great than or equal to 1.') end if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1 invalid_properties.push('invalid value for "previous_event_id", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
394 395 396 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 394 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 400 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
388 389 390 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 388 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/talon_one/models/integration_event_v3_request.rb', line 214 def valid? return false if @profile_id.nil? return false if !@store_integration_id.nil? && @store_integration_id.to_s.length > 1000 return false if !@store_integration_id.nil? && @store_integration_id.to_s.length < 1 return false if @integration_id.nil? return false if @integration_id.to_s.length < 1 return false if @type.nil? return false if @type.to_s.length < 1 return false if !@connected_session_id.nil? && @connected_session_id.to_s.length < 1 return false if !@previous_event_id.nil? && @previous_event_id.to_s.length < 1 true end |