Class: TalonOne::IntegrationHubEventPayloadCouponBasedNotifications

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadCouponBasedNotifications

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventPayloadCouponBasedNotifications` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventPayloadCouponBasedNotifications`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'usage_limit')
    self.usage_limit = attributes[:'usage_limit']
  end

  if attributes.key?(:'discount_limit')
    self.discount_limit = attributes[:'discount_limit']
  end

  if attributes.key?(:'reservation_limit')
    self.reservation_limit = attributes[:'reservation_limit']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'usage_counter')
    self.usage_counter = attributes[:'usage_counter']
  end

  if attributes.key?(:'discount_counter')
    self.discount_counter = attributes[:'discount_counter']
  end

  if attributes.key?(:'discount_remainder')
    self.discount_remainder = attributes[:'discount_remainder']
  end

  if attributes.key?(:'referral_id')
    self.referral_id = attributes[:'referral_id']
  end

  if attributes.key?(:'recipient_integration_id')
    self.recipient_integration_id = attributes[:'recipient_integration_id']
  end

  if attributes.key?(:'import_id')
    self.import_id = attributes[:'import_id']
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'source_of_event')
    self.source_of_event = attributes[:'source_of_event']
  end

  if attributes.key?(:'employee_name')
    self.employee_name = attributes[:'employee_name']
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



49
50
51
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 49

def attributes
  @attributes
end

#batch_idObject

Returns the value of attribute batch_id.



47
48
49
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 47

def batch_id
  @batch_id
end

#campaign_idObject

Returns the value of attribute campaign_id.



21
22
23
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 21

def campaign_id
  @campaign_id
end

#createdObject

Returns the value of attribute created.



19
20
21
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 19

def created
  @created
end

#discount_counterObject

Returns the value of attribute discount_counter.



37
38
39
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 37

def discount_counter
  @discount_counter
end

#discount_limitObject

Returns the value of attribute discount_limit.



27
28
29
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 27

def discount_limit
  @discount_limit
end

#discount_remainderObject

Returns the value of attribute discount_remainder.



39
40
41
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 39

def discount_remainder
  @discount_remainder
end

#employee_nameObject

Returns the value of attribute employee_name.



58
59
60
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 58

def employee_name
  @employee_name
end

#expiry_dateObject

Returns the value of attribute expiry_date.



33
34
35
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 33

def expiry_date
  @expiry_date
end

#idObject

Returns the value of attribute id.



17
18
19
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 17

def id
  @id
end

#import_idObject

Returns the value of attribute import_id.



45
46
47
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 45

def import_id
  @import_id
end

#limitsObject

Returns the value of attribute limits.



51
52
53
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 51

def limits
  @limits
end

#published_atObject

Timestamp when the event was published.



54
55
56
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 54

def published_at
  @published_at
end

#recipient_integration_idObject

Returns the value of attribute recipient_integration_id.



43
44
45
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 43

def recipient_integration_id
  @recipient_integration_id
end

#referral_idObject

Returns the value of attribute referral_id.



41
42
43
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 41

def referral_id
  @referral_id
end

#reservation_limitObject

Returns the value of attribute reservation_limit.



29
30
31
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 29

def reservation_limit
  @reservation_limit
end

#source_of_eventObject

Returns the value of attribute source_of_event.



56
57
58
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 56

def source_of_event
  @source_of_event
end

#start_dateObject

Returns the value of attribute start_date.



31
32
33
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 31

def start_date
  @start_date
end

#usage_counterObject

Returns the value of attribute usage_counter.



35
36
37
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 35

def usage_counter
  @usage_counter
end

#usage_limitObject

Returns the value of attribute usage_limit.



25
26
27
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 25

def usage_limit
  @usage_limit
end

#valueObject

Returns the value of attribute value.



23
24
25
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 23

def value
  @value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 61

def self.attribute_map
  {
    :'id' => :'Id',
    :'created' => :'Created',
    :'campaign_id' => :'CampaignId',
    :'value' => :'Value',
    :'usage_limit' => :'UsageLimit',
    :'discount_limit' => :'DiscountLimit',
    :'reservation_limit' => :'ReservationLimit',
    :'start_date' => :'StartDate',
    :'expiry_date' => :'ExpiryDate',
    :'usage_counter' => :'UsageCounter',
    :'discount_counter' => :'DiscountCounter',
    :'discount_remainder' => :'DiscountRemainder',
    :'referral_id' => :'ReferralId',
    :'recipient_integration_id' => :'RecipientIntegrationId',
    :'import_id' => :'ImportId',
    :'batch_id' => :'BatchId',
    :'attributes' => :'Attributes',
    :'limits' => :'Limits',
    :'published_at' => :'PublishedAt',
    :'source_of_event' => :'SourceOfEvent',
    :'employee_name' => :'EmployeeName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 323

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 88

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'DateTime',
    :'campaign_id' => :'Integer',
    :'value' => :'String',
    :'usage_limit' => :'Integer',
    :'discount_limit' => :'Float',
    :'reservation_limit' => :'Integer',
    :'start_date' => :'DateTime',
    :'expiry_date' => :'DateTime',
    :'usage_counter' => :'Integer',
    :'discount_counter' => :'Float',
    :'discount_remainder' => :'Float',
    :'referral_id' => :'Integer',
    :'recipient_integration_id' => :'String',
    :'import_id' => :'Integer',
    :'batch_id' => :'String',
    :'attributes' => :'Object',
    :'limits' => :'Array<IntegrationHubEventPayloadCouponBasedNotificationsLimits>',
    :'published_at' => :'DateTime',
    :'source_of_event' => :'String',
    :'employee_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      campaign_id == o.campaign_id &&
      value == o.value &&
      usage_limit == o.usage_limit &&
      discount_limit == o.discount_limit &&
      reservation_limit == o.reservation_limit &&
      start_date == o.start_date &&
      expiry_date == o.expiry_date &&
      usage_counter == o.usage_counter &&
      discount_counter == o.discount_counter &&
      discount_remainder == o.discount_remainder &&
      referral_id == o.referral_id &&
      recipient_integration_id == o.recipient_integration_id &&
      import_id == o.import_id &&
      batch_id == o.batch_id &&
      attributes == o.attributes &&
      limits == o.limits &&
      published_at == o.published_at &&
      source_of_event == o.source_of_event &&
      employee_name == o.employee_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 351

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 420

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 330

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 316

def hash
  [id, created, campaign_id, value, usage_limit, discount_limit, reservation_limit, start_date, expiry_date, usage_counter, discount_counter, discount_remainder, referral_id, recipient_integration_id, import_id, batch_id, attributes, limits, published_at, source_of_event, employee_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 224

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @campaign_id.nil?
    invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @usage_limit.nil?
    invalid_properties.push('invalid value for "usage_limit", usage_limit cannot be nil.')
  end

  if @usage_counter.nil?
    invalid_properties.push('invalid value for "usage_counter", usage_counter cannot be nil.')
  end

  if @published_at.nil?
    invalid_properties.push('invalid value for "published_at", published_at cannot be nil.')
  end

  if @source_of_event.nil?
    invalid_properties.push('invalid value for "source_of_event", source_of_event cannot be nil.')
  end

  if @employee_name.nil?
    invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



396
397
398
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 396

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 402

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



390
391
392
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 390

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/talon_one/models/integration_hub_event_payload_coupon_based_notifications.rb', line 267

def valid?
  return false if @id.nil?
  return false if @created.nil?
  return false if @campaign_id.nil?
  return false if @value.nil?
  return false if @usage_limit.nil?
  return false if @usage_counter.nil?
  return false if @published_at.nil?
  return false if @source_of_event.nil?
  return false if @employee_name.nil?
  true
end