Class: TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::IntegrationHubEventPayloadLoyaltyProfileBasedTierUpgradeNotification`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_integration_id')
    self.profile_integration_id = attributes[:'profile_integration_id']
  end

  if attributes.key?(:'loyalty_program_id')
    self.loyalty_program_id = attributes[:'loyalty_program_id']
  end

  if attributes.key?(:'subledger_id')
    self.subledger_id = attributes[:'subledger_id']
  end

  if attributes.key?(:'source_of_event')
    self.source_of_event = attributes[:'source_of_event']
  end

  if attributes.key?(:'current_tier')
    self.current_tier = attributes[:'current_tier']
  end

  if attributes.key?(:'current_points')
    self.current_points = attributes[:'current_points']
  end

  if attributes.key?(:'old_tier')
    self.old_tier = attributes[:'old_tier']
  end

  if attributes.key?(:'points_required_to_the_next_tier')
    self.points_required_to_the_next_tier = attributes[:'points_required_to_the_next_tier']
  end

  if attributes.key?(:'next_tier')
    self.next_tier = attributes[:'next_tier']
  end

  if attributes.key?(:'tier_expiration_date')
    self.tier_expiration_date = attributes[:'tier_expiration_date']
  end

  if attributes.key?(:'timestamp_of_tier_change')
    self.timestamp_of_tier_change = attributes[:'timestamp_of_tier_change']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end
end

Instance Attribute Details

#current_pointsObject

Returns the value of attribute current_points.



27
28
29
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 27

def current_points
  @current_points
end

#current_tierObject

Returns the value of attribute current_tier.



25
26
27
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 25

def current_tier
  @current_tier
end

#loyalty_program_idObject

Returns the value of attribute loyalty_program_id.



19
20
21
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 19

def loyalty_program_id
  @loyalty_program_id
end

#next_tierObject

Returns the value of attribute next_tier.



33
34
35
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 33

def next_tier
  @next_tier
end

#old_tierObject

Returns the value of attribute old_tier.



29
30
31
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 29

def old_tier
  @old_tier
end

#points_required_to_the_next_tierObject

Returns the value of attribute points_required_to_the_next_tier.



31
32
33
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 31

def points_required_to_the_next_tier
  @points_required_to_the_next_tier
end

#profile_integration_idObject

Returns the value of attribute profile_integration_id.



17
18
19
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 17

def profile_integration_id
  @profile_integration_id
end

#published_atObject

Timestamp when the event was published.



40
41
42
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 40

def published_at
  @published_at
end

#source_of_eventObject

Returns the value of attribute source_of_event.



23
24
25
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 23

def source_of_event
  @source_of_event
end

#subledger_idObject

Returns the value of attribute subledger_id.



21
22
23
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 21

def subledger_id
  @subledger_id
end

#tier_expiration_dateObject

Returns the value of attribute tier_expiration_date.



35
36
37
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 35

def tier_expiration_date
  @tier_expiration_date
end

#timestamp_of_tier_changeObject

Returns the value of attribute timestamp_of_tier_change.



37
38
39
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 37

def timestamp_of_tier_change
  @timestamp_of_tier_change
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 43

def self.attribute_map
  {
    :'profile_integration_id' => :'ProfileIntegrationID',
    :'loyalty_program_id' => :'LoyaltyProgramID',
    :'subledger_id' => :'SubledgerID',
    :'source_of_event' => :'SourceOfEvent',
    :'current_tier' => :'CurrentTier',
    :'current_points' => :'CurrentPoints',
    :'old_tier' => :'OldTier',
    :'points_required_to_the_next_tier' => :'PointsRequiredToTheNextTier',
    :'next_tier' => :'NextTier',
    :'tier_expiration_date' => :'TierExpirationDate',
    :'timestamp_of_tier_change' => :'TimestampOfTierChange',
    :'published_at' => :'PublishedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 225

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 61

def self.openapi_types
  {
    :'profile_integration_id' => :'String',
    :'loyalty_program_id' => :'Integer',
    :'subledger_id' => :'String',
    :'source_of_event' => :'String',
    :'current_tier' => :'String',
    :'current_points' => :'Float',
    :'old_tier' => :'String',
    :'points_required_to_the_next_tier' => :'Float',
    :'next_tier' => :'String',
    :'tier_expiration_date' => :'DateTime',
    :'timestamp_of_tier_change' => :'DateTime',
    :'published_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_integration_id == o.profile_integration_id &&
      loyalty_program_id == o.loyalty_program_id &&
      subledger_id == o.subledger_id &&
      source_of_event == o.source_of_event &&
      current_tier == o.current_tier &&
      current_points == o.current_points &&
      old_tier == o.old_tier &&
      points_required_to_the_next_tier == o.points_required_to_the_next_tier &&
      next_tier == o.next_tier &&
      tier_expiration_date == o.tier_expiration_date &&
      timestamp_of_tier_change == o.timestamp_of_tier_change &&
      published_at == o.published_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 322

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 232

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 218

def hash
  [profile_integration_id, loyalty_program_id, subledger_id, source_of_event, current_tier, current_points, old_tier, points_required_to_the_next_tier, next_tier, tier_expiration_date, timestamp_of_tier_change, published_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 150

def list_invalid_properties
  invalid_properties = Array.new
  if @profile_integration_id.nil?
    invalid_properties.push('invalid value for "profile_integration_id", profile_integration_id cannot be nil.')
  end

  if @loyalty_program_id.nil?
    invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.')
  end

  if @subledger_id.nil?
    invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.')
  end

  if @source_of_event.nil?
    invalid_properties.push('invalid value for "source_of_event", source_of_event cannot be nil.')
  end

  if @current_points.nil?
    invalid_properties.push('invalid value for "current_points", current_points cannot be nil.')
  end

  if @published_at.nil?
    invalid_properties.push('invalid value for "published_at", published_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 298

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



292
293
294
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 292

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
# File 'lib/talon_one/models/integration_hub_event_payload_loyalty_profile_based_tier_upgrade_notification.rb', line 181

def valid?
  return false if @profile_integration_id.nil?
  return false if @loyalty_program_id.nil?
  return false if @subledger_id.nil?
  return false if @source_of_event.nil?
  return false if @current_points.nil?
  return false if @published_at.nil?
  true
end