Class: TalonOne::LoyaltyCard
- Inherits:
-
Object
- Object
- TalonOne::LoyaltyCard
- Defined in:
- lib/talon_one/models/loyalty_card.rb
Instance Attribute Summary collapse
-
#batch_id ⇒ Object
The ID of the batch in which the loyalty card was created.
-
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
-
#created ⇒ Object
The time this entity was created.
-
#id ⇒ Object
The internal ID of this entity.
-
#identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
-
#ledger ⇒ Object
Returns the value of attribute ledger.
-
#modified ⇒ Object
Timestamp of the most recent update of the loyalty card.
-
#new_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
-
#old_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
-
#profiles ⇒ Object
Integration IDs of the customers profiles linked to the card.
-
#program_id ⇒ Object
The ID of the loyalty program that owns this entity.
-
#program_name ⇒ Object
The integration name of the loyalty program that owns this entity.
-
#program_title ⇒ Object
The Campaign Manager-displayed name of the loyalty program that owns this entity.
-
#status ⇒ Object
Status of the loyalty card.
-
#subledgers ⇒ Object
Displays point balances of the card in the subledgers of the loyalty program.
-
#users_per_card_limit ⇒ Object
The max amount of customer profiles that can be linked to the card.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoyaltyCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LoyaltyCard
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/talon_one/models/loyalty_card.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::LoyaltyCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::LoyaltyCard`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'created') self.created = attributes[:'created'] end if attributes.key?(:'program_id') self.program_id = attributes[:'program_id'] end if attributes.key?(:'program_name') self.program_name = attributes[:'program_name'] end if attributes.key?(:'program_title') self.program_title = attributes[:'program_title'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'block_reason') self.block_reason = attributes[:'block_reason'] end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'users_per_card_limit') self.users_per_card_limit = attributes[:'users_per_card_limit'] end if attributes.key?(:'profiles') if (value = attributes[:'profiles']).is_a?(Array) self.profiles = value end end if attributes.key?(:'ledger') self.ledger = attributes[:'ledger'] end if attributes.key?(:'subledgers') if (value = attributes[:'subledgers']).is_a?(Hash) self.subledgers = value end end if attributes.key?(:'modified') self.modified = attributes[:'modified'] end if attributes.key?(:'old_card_identifier') self.old_card_identifier = attributes[:'old_card_identifier'] end if attributes.key?(:'new_card_identifier') self.new_card_identifier = attributes[:'new_card_identifier'] end if attributes.key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end end |
Instance Attribute Details
#batch_id ⇒ Object
The ID of the batch in which the loyalty card was created.
62 63 64 |
# File 'lib/talon_one/models/loyalty_card.rb', line 62 def batch_id @batch_id end |
#block_reason ⇒ Object
Reason for transferring and blocking the loyalty card.
36 37 38 |
# File 'lib/talon_one/models/loyalty_card.rb', line 36 def block_reason @block_reason end |
#created ⇒ Object
The time this entity was created.
21 22 23 |
# File 'lib/talon_one/models/loyalty_card.rb', line 21 def created @created end |
#id ⇒ Object
The internal ID of this entity.
18 19 20 |
# File 'lib/talon_one/models/loyalty_card.rb', line 18 def id @id end |
#identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
39 40 41 |
# File 'lib/talon_one/models/loyalty_card.rb', line 39 def identifier @identifier end |
#ledger ⇒ Object
Returns the value of attribute ledger.
47 48 49 |
# File 'lib/talon_one/models/loyalty_card.rb', line 47 def ledger @ledger end |
#modified ⇒ Object
Timestamp of the most recent update of the loyalty card.
53 54 55 |
# File 'lib/talon_one/models/loyalty_card.rb', line 53 def modified @modified end |
#new_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
59 60 61 |
# File 'lib/talon_one/models/loyalty_card.rb', line 59 def new_card_identifier @new_card_identifier end |
#old_card_identifier ⇒ Object
The identifier of the loyalty card, which must match the regular expression ‘^[A-Za-z0-9._%+@-]+$`.
56 57 58 |
# File 'lib/talon_one/models/loyalty_card.rb', line 56 def old_card_identifier @old_card_identifier end |
#profiles ⇒ Object
Integration IDs of the customers profiles linked to the card.
45 46 47 |
# File 'lib/talon_one/models/loyalty_card.rb', line 45 def profiles @profiles end |
#program_id ⇒ Object
The ID of the loyalty program that owns this entity.
24 25 26 |
# File 'lib/talon_one/models/loyalty_card.rb', line 24 def program_id @program_id end |
#program_name ⇒ Object
The integration name of the loyalty program that owns this entity.
27 28 29 |
# File 'lib/talon_one/models/loyalty_card.rb', line 27 def program_name @program_name end |
#program_title ⇒ Object
The Campaign Manager-displayed name of the loyalty program that owns this entity.
30 31 32 |
# File 'lib/talon_one/models/loyalty_card.rb', line 30 def program_title @program_title end |
#status ⇒ Object
Status of the loyalty card. Can be ‘active` or `inactive`.
33 34 35 |
# File 'lib/talon_one/models/loyalty_card.rb', line 33 def status @status end |
#subledgers ⇒ Object
Displays point balances of the card in the subledgers of the loyalty program.
50 51 52 |
# File 'lib/talon_one/models/loyalty_card.rb', line 50 def subledgers @subledgers end |
#users_per_card_limit ⇒ Object
The max amount of customer profiles that can be linked to the card. 0 means unlimited.
42 43 44 |
# File 'lib/talon_one/models/loyalty_card.rb', line 42 def users_per_card_limit @users_per_card_limit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/talon_one/models/loyalty_card.rb', line 65 def self.attribute_map { :'id' => :'id', :'created' => :'created', :'program_id' => :'programID', :'program_name' => :'programName', :'program_title' => :'programTitle', :'status' => :'status', :'block_reason' => :'blockReason', :'identifier' => :'identifier', :'users_per_card_limit' => :'usersPerCardLimit', :'profiles' => :'profiles', :'ledger' => :'ledger', :'subledgers' => :'subledgers', :'modified' => :'modified', :'old_card_identifier' => :'oldCardIdentifier', :'new_card_identifier' => :'newCardIdentifier', :'batch_id' => :'batchId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
407 408 409 |
# File 'lib/talon_one/models/loyalty_card.rb', line 407 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/talon_one/models/loyalty_card.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/talon_one/models/loyalty_card.rb', line 87 def self.openapi_types { :'id' => :'Integer', :'created' => :'DateTime', :'program_id' => :'Integer', :'program_name' => :'String', :'program_title' => :'String', :'status' => :'String', :'block_reason' => :'String', :'identifier' => :'String', :'users_per_card_limit' => :'Integer', :'profiles' => :'Array<LoyaltyCardProfileRegistration>', :'ledger' => :'LedgerInfo', :'subledgers' => :'Hash<String, LedgerInfo>', :'modified' => :'DateTime', :'old_card_identifier' => :'String', :'new_card_identifier' => :'String', :'batch_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/talon_one/models/loyalty_card.rb', line 371 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created == o.created && program_id == o.program_id && program_name == o.program_name && program_title == o.program_title && status == o.status && block_reason == o.block_reason && identifier == o.identifier && users_per_card_limit == o.users_per_card_limit && profiles == o.profiles && ledger == o.ledger && subledgers == o.subledgers && modified == o.modified && old_card_identifier == o.old_card_identifier && new_card_identifier == o.new_card_identifier && batch_id == o.batch_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/talon_one/models/loyalty_card.rb', line 435 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/talon_one/models/loyalty_card.rb', line 504 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/talon_one/models/loyalty_card.rb', line 414 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
394 395 396 |
# File 'lib/talon_one/models/loyalty_card.rb', line 394 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
400 401 402 |
# File 'lib/talon_one/models/loyalty_card.rb', line 400 def hash [id, created, program_id, program_name, program_title, status, block_reason, identifier, users_per_card_limit, profiles, ledger, subledgers, modified, old_card_identifier, new_card_identifier, batch_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/talon_one/models/loyalty_card.rb', line 200 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @program_id.nil? invalid_properties.push('invalid value for "program_id", program_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @identifier.to_s.length > 108 invalid_properties.push('invalid value for "identifier", the character length must be smaller than or equal to 108.') end if @identifier.to_s.length < 4 invalid_properties.push('invalid value for "identifier", the character length must be great than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if @identifier !~ pattern invalid_properties.push("invalid value for \"identifier\", must conform to the pattern #{pattern}.") end if @users_per_card_limit.nil? invalid_properties.push('invalid value for "users_per_card_limit", users_per_card_limit cannot be nil.') end if @users_per_card_limit < 0 invalid_properties.push('invalid value for "users_per_card_limit", must be greater than or equal to 0.') end if !@old_card_identifier.nil? && @old_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "old_card_identifier", the character length must be smaller than or equal to 108.') end if !@old_card_identifier.nil? && @old_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "old_card_identifier", the character length must be great than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@old_card_identifier.nil? && @old_card_identifier !~ pattern invalid_properties.push("invalid value for \"old_card_identifier\", must conform to the pattern #{pattern}.") end if !@new_card_identifier.nil? && @new_card_identifier.to_s.length > 108 invalid_properties.push('invalid value for "new_card_identifier", the character length must be smaller than or equal to 108.') end if !@new_card_identifier.nil? && @new_card_identifier.to_s.length < 4 invalid_properties.push('invalid value for "new_card_identifier", the character length must be great than or equal to 4.') end pattern = Regexp.new(/^[A-Za-z0-9._%+@-]+$/) if !@new_card_identifier.nil? && @new_card_identifier !~ pattern invalid_properties.push("invalid value for \"new_card_identifier\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
480 481 482 |
# File 'lib/talon_one/models/loyalty_card.rb', line 480 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/talon_one/models/loyalty_card.rb', line 486 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
474 475 476 |
# File 'lib/talon_one/models/loyalty_card.rb', line 474 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/talon_one/models/loyalty_card.rb', line 274 def valid? return false if @id.nil? return false if @created.nil? return false if @program_id.nil? return false if @status.nil? return false if @identifier.nil? return false if @identifier.to_s.length > 108 return false if @identifier.to_s.length < 4 return false if @identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) return false if @users_per_card_limit.nil? return false if @users_per_card_limit < 0 return false if !@old_card_identifier.nil? && @old_card_identifier.to_s.length > 108 return false if !@old_card_identifier.nil? && @old_card_identifier.to_s.length < 4 return false if !@old_card_identifier.nil? && @old_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) return false if !@new_card_identifier.nil? && @new_card_identifier.to_s.length > 108 return false if !@new_card_identifier.nil? && @new_card_identifier.to_s.length < 4 return false if !@new_card_identifier.nil? && @new_card_identifier !~ Regexp.new(/^[A-Za-z0-9._%+@-]+$/) true end |