Class: TalonOne::RevisionVersion
- Inherits:
-
Object
- Object
- TalonOne::RevisionVersion
- Defined in:
- lib/talon_one/models/revision_version.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#active_ruleset_id ⇒ Object
The ID of the ruleset this campaign will use.
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
-
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
-
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
-
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
-
#created ⇒ Object
Returns the value of attribute created.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#description ⇒ Object
A detailed description of the campaign.
-
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
-
#features ⇒ Object
A list of features for the campaign.
-
#id ⇒ Object
Unique ID for this entity.
-
#limits ⇒ Object
The set of limits that will operate for this campaign version.
-
#name ⇒ Object
A user-facing name for this campaign.
-
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
-
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
-
#revision_id ⇒ Object
Returns the value of attribute revision_id.
-
#start_time ⇒ Object
Timestamp when the campaign will become active.
-
#tags ⇒ Object
A list of tags for the campaign.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RevisionVersion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RevisionVersion
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/talon_one/models/revision_version.rb', line 159 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::RevisionVersion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::RevisionVersion`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'created') self.created = attributes[:'created'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'revision_id') self.revision_id = attributes[:'revision_id'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'active_ruleset_id') self.active_ruleset_id = attributes[:'active_ruleset_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'coupon_settings') self.coupon_settings = attributes[:'coupon_settings'] end if attributes.key?(:'referral_settings') self.referral_settings = attributes[:'referral_settings'] end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Array) self.limits = value end end if attributes.key?(:'reevaluate_on_return') self.reevaluate_on_return = attributes[:'reevaluate_on_return'] end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end end if attributes.key?(:'coupon_attributes') self.coupon_attributes = attributes[:'coupon_attributes'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/talon_one/models/revision_version.rb', line 20 def account_id @account_id end |
#active_ruleset_id ⇒ Object
The ID of the ruleset this campaign will use.
50 51 52 |
# File 'lib/talon_one/models/revision_version.rb', line 50 def active_ruleset_id @active_ruleset_id end |
#application_id ⇒ Object
Returns the value of attribute application_id.
22 23 24 |
# File 'lib/talon_one/models/revision_version.rb', line 22 def application_id @application_id end |
#attributes ⇒ Object
Arbitrary properties associated with this campaign.
44 45 46 |
# File 'lib/talon_one/models/revision_version.rb', line 44 def attributes @attributes end |
#campaign_id ⇒ Object
Returns the value of attribute campaign_id.
24 25 26 |
# File 'lib/talon_one/models/revision_version.rb', line 24 def campaign_id @campaign_id end |
#coupon_attributes ⇒ Object
Arbitrary properties associated with coupons in this campaign.
69 70 71 |
# File 'lib/talon_one/models/revision_version.rb', line 69 def coupon_attributes @coupon_attributes end |
#coupon_settings ⇒ Object
Returns the value of attribute coupon_settings.
55 56 57 |
# File 'lib/talon_one/models/revision_version.rb', line 55 def coupon_settings @coupon_settings end |
#created ⇒ Object
Returns the value of attribute created.
26 27 28 |
# File 'lib/talon_one/models/revision_version.rb', line 26 def created @created end |
#created_by ⇒ Object
Returns the value of attribute created_by.
28 29 30 |
# File 'lib/talon_one/models/revision_version.rb', line 28 def created_by @created_by end |
#description ⇒ Object
A detailed description of the campaign.
47 48 49 |
# File 'lib/talon_one/models/revision_version.rb', line 47 def description @description end |
#end_time ⇒ Object
Timestamp when the campaign will become inactive.
41 42 43 |
# File 'lib/talon_one/models/revision_version.rb', line 41 def end_time @end_time end |
#features ⇒ Object
A list of features for the campaign.
66 67 68 |
# File 'lib/talon_one/models/revision_version.rb', line 66 def features @features end |
#id ⇒ Object
Unique ID for this entity. Not to be confused with the Integration ID, which is set by your integration layer and used in most endpoints.
18 19 20 |
# File 'lib/talon_one/models/revision_version.rb', line 18 def id @id end |
#limits ⇒ Object
The set of limits that will operate for this campaign version.
60 61 62 |
# File 'lib/talon_one/models/revision_version.rb', line 60 def limits @limits end |
#name ⇒ Object
A user-facing name for this campaign.
35 36 37 |
# File 'lib/talon_one/models/revision_version.rb', line 35 def name @name end |
#reevaluate_on_return ⇒ Object
Indicates whether this campaign should be reevaluated when a customer returns an item.
63 64 65 |
# File 'lib/talon_one/models/revision_version.rb', line 63 def reevaluate_on_return @reevaluate_on_return end |
#referral_settings ⇒ Object
Returns the value of attribute referral_settings.
57 58 59 |
# File 'lib/talon_one/models/revision_version.rb', line 57 def referral_settings @referral_settings end |
#revision_id ⇒ Object
Returns the value of attribute revision_id.
30 31 32 |
# File 'lib/talon_one/models/revision_version.rb', line 30 def revision_id @revision_id end |
#start_time ⇒ Object
Timestamp when the campaign will become active.
38 39 40 |
# File 'lib/talon_one/models/revision_version.rb', line 38 def start_time @start_time end |
#tags ⇒ Object
A list of tags for the campaign.
53 54 55 |
# File 'lib/talon_one/models/revision_version.rb', line 53 def @tags end |
#version ⇒ Object
Returns the value of attribute version.
32 33 34 |
# File 'lib/talon_one/models/revision_version.rb', line 32 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/talon_one/models/revision_version.rb', line 94 def self.attribute_map { :'id' => :'id', :'account_id' => :'accountId', :'application_id' => :'applicationId', :'campaign_id' => :'campaignId', :'created' => :'created', :'created_by' => :'createdBy', :'revision_id' => :'revisionId', :'version' => :'version', :'name' => :'name', :'start_time' => :'startTime', :'end_time' => :'endTime', :'attributes' => :'attributes', :'description' => :'description', :'active_ruleset_id' => :'activeRulesetId', :'tags' => :'tags', :'coupon_settings' => :'couponSettings', :'referral_settings' => :'referralSettings', :'limits' => :'limits', :'reevaluate_on_return' => :'reevaluateOnReturn', :'features' => :'features', :'coupon_attributes' => :'couponAttributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
374 375 376 |
# File 'lib/talon_one/models/revision_version.rb', line 374 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
148 149 150 151 152 153 154 155 |
# File 'lib/talon_one/models/revision_version.rb', line 148 def self.openapi_nullable Set.new([ :'start_time', :'end_time', :'description', :'active_ruleset_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/talon_one/models/revision_version.rb', line 121 def self.openapi_types { :'id' => :'Integer', :'account_id' => :'Integer', :'application_id' => :'Integer', :'campaign_id' => :'Integer', :'created' => :'DateTime', :'created_by' => :'Integer', :'revision_id' => :'Integer', :'version' => :'Integer', :'name' => :'String', :'start_time' => :'DateTime', :'end_time' => :'DateTime', :'attributes' => :'Object', :'description' => :'String', :'active_ruleset_id' => :'Integer', :'tags' => :'Array<String>', :'coupon_settings' => :'CodeGeneratorSettings', :'referral_settings' => :'CodeGeneratorSettings', :'limits' => :'Array<LimitConfig>', :'reevaluate_on_return' => :'Boolean', :'features' => :'Array<String>', :'coupon_attributes' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/talon_one/models/revision_version.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && account_id == o.account_id && application_id == o.application_id && campaign_id == o.campaign_id && created == o.created && created_by == o.created_by && revision_id == o.revision_id && version == o.version && name == o.name && start_time == o.start_time && end_time == o.end_time && attributes == o.attributes && description == o.description && active_ruleset_id == o.active_ruleset_id && == o. && coupon_settings == o.coupon_settings && referral_settings == o.referral_settings && limits == o.limits && reevaluate_on_return == o.reevaluate_on_return && features == o.features && coupon_attributes == o.coupon_attributes end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/talon_one/models/revision_version.rb', line 402 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/talon_one/models/revision_version.rb', line 471 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/talon_one/models/revision_version.rb', line 381 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
361 362 363 |
# File 'lib/talon_one/models/revision_version.rb', line 361 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
367 368 369 |
# File 'lib/talon_one/models/revision_version.rb', line 367 def hash [id, account_id, application_id, campaign_id, created, created_by, revision_id, version, name, start_time, end_time, attributes, description, active_ruleset_id, , coupon_settings, referral_settings, limits, reevaluate_on_return, features, coupon_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/talon_one/models/revision_version.rb', line 265 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @campaign_id.nil? invalid_properties.push('invalid value for "campaign_id", campaign_id cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @revision_id.nil? invalid_properties.push('invalid value for "revision_id", revision_id cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
447 448 449 |
# File 'lib/talon_one/models/revision_version.rb', line 447 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/talon_one/models/revision_version.rb', line 453 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
441 442 443 |
# File 'lib/talon_one/models/revision_version.rb', line 441 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/talon_one/models/revision_version.rb', line 308 def valid? return false if @id.nil? return false if @account_id.nil? return false if @application_id.nil? return false if @campaign_id.nil? return false if @created.nil? return false if @created_by.nil? return false if @revision_id.nil? return false if @version.nil? return false if !@name.nil? && @name.to_s.length < 1 true end |