Class: TalonOne::Reward

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/reward.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Reward

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/talon_one/models/reward.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::Reward` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::Reward`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'api_name')
    self.api_name = attributes[:'api_name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'application_ids')
    if (value = attributes[:'application_ids']).is_a?(Array)
      self.application_ids = value
    end
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#account_idObject

The ID of the account that owns this entity.



24
25
26
# File 'lib/talon_one/models/reward.rb', line 24

def 
  @account_id
end

#api_nameObject

A unique identifier used to reference the reward in API integrations.



30
31
32
# File 'lib/talon_one/models/reward.rb', line 30

def api_name
  @api_name
end

#application_idsObject

The IDs of the Applications this reward is connected to. Note: Currently, a reward can only be connected to one Application.



36
37
38
# File 'lib/talon_one/models/reward.rb', line 36

def application_ids
  @application_ids
end

#createdObject

The time this entity was created.



21
22
23
# File 'lib/talon_one/models/reward.rb', line 21

def created
  @created
end

#descriptionObject

A description of the reward.



33
34
35
# File 'lib/talon_one/models/reward.rb', line 33

def description
  @description
end

#idObject

The internal ID of this entity.



18
19
20
# File 'lib/talon_one/models/reward.rb', line 18

def id
  @id
end

#nameObject

The name of the reward.



27
28
29
# File 'lib/talon_one/models/reward.rb', line 27

def name
  @name
end

#sandboxObject

Indicates if this is a live or sandbox reward. Rewards of a given type can only be connected to Applications of the same type.



39
40
41
# File 'lib/talon_one/models/reward.rb', line 39

def sandbox
  @sandbox
end

#statusObject

The status of the reward.



42
43
44
# File 'lib/talon_one/models/reward.rb', line 42

def status
  @status
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/talon_one/models/reward.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'api_name' => :'apiName',
    :'description' => :'description',
    :'application_ids' => :'applicationIds',
    :'sandbox' => :'sandbox',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
# File 'lib/talon_one/models/reward.rb', line 290

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/talon_one/models/reward.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/talon_one/models/reward.rb', line 82

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'DateTime',
    :'account_id' => :'Integer',
    :'name' => :'String',
    :'api_name' => :'String',
    :'description' => :'String',
    :'application_ids' => :'Array<Integer>',
    :'sandbox' => :'Boolean',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/talon_one/models/reward.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
       == o. &&
      name == o.name &&
      api_name == o.api_name &&
      description == o.description &&
      application_ids == o.application_ids &&
      sandbox == o.sandbox &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/talon_one/models/reward.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/talon_one/models/reward.rb', line 387

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/talon_one/models/reward.rb', line 297

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/talon_one/models/reward.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/talon_one/models/reward.rb', line 283

def hash
  [id, created, , name, api_name, description, application_ids, sandbox, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/talon_one/models/reward.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @api_name.nil?
    invalid_properties.push('invalid value for "api_name", api_name cannot be nil.')
  end

  if @api_name.to_s.length < 1
    invalid_properties.push('invalid value for "api_name", the character length must be great than or equal to 1.')
  end

  if @application_ids.nil?
    invalid_properties.push('invalid value for "application_ids", application_ids cannot be nil.')
  end

  if @sandbox.nil?
    invalid_properties.push('invalid value for "sandbox", sandbox cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
# File 'lib/talon_one/models/reward.rb', line 363

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/talon_one/models/reward.rb', line 369

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



357
358
359
# File 'lib/talon_one/models/reward.rb', line 357

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/talon_one/models/reward.rb', line 205

def valid?
  return false if @id.nil?
  return false if @created.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @api_name.nil?
  return false if @api_name.to_s.length < 1
  return false if @application_ids.nil?
  return false if @sandbox.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["active", "inactive"])
  return false unless status_validator.valid?(@status)
  true
end