Class: TalonOne::StrikethroughLabelingNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/strikethrough_labeling_notification.rb

Overview

The strikethrough labels notification for an application.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StrikethroughLabelingNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::StrikethroughLabelingNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::StrikethroughLabelingNotification`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'valid_from')
    self.valid_from = attributes[:'valid_from']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'current_batch')
    self.current_batch = attributes[:'current_batch']
  end

  if attributes.key?(:'total_batches')
    self.total_batches = attributes[:'total_batches']
  end

  if attributes.key?(:'trigger')
    self.trigger = attributes[:'trigger']
  end

  if attributes.key?(:'changed_items')
    if (value = attributes[:'changed_items']).is_a?(Array)
      self.changed_items = value
    end
  end

  if attributes.key?(:'notification_type')
    self.notification_type = attributes[:'notification_type']
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  end
end

Instance Attribute Details

#application_idObject

The ID of the Application to which the catalog items labels belongs.



25
26
27
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 25

def application_id
  @application_id
end

#changed_itemsObject

Returns the value of attribute changed_items.



35
36
37
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 35

def changed_items
  @changed_items
end

#current_batchObject

The batch number of the notification. Notifications might be sent in different batches.



28
29
30
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 28

def current_batch
  @current_batch
end

#notification_typeObject

The type of notification.



38
39
40
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 38

def notification_type
  @notification_type
end

#sent_atObject

Timestamp at which the notification was sent.



41
42
43
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 41

def sent_at
  @sent_at
end

#total_batchesObject

The total number of batches for the notification.



31
32
33
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 31

def total_batches
  @total_batches
end

#triggerObject

Returns the value of attribute trigger.



33
34
35
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 33

def trigger
  @trigger
end

#valid_fromObject

Timestamp at which the strikethrough pricing update becomes valid. Set for scheduled strikethrough pricing updates (version: v2) only.



22
23
24
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 22

def valid_from
  @valid_from
end

#versionObject

The version of the strikethrough pricing notification.



19
20
21
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 19

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 66

def self.attribute_map
  {
    :'version' => :'version',
    :'valid_from' => :'validFrom',
    :'application_id' => :'applicationId',
    :'current_batch' => :'currentBatch',
    :'total_batches' => :'totalBatches',
    :'trigger' => :'trigger',
    :'changed_items' => :'changedItems',
    :'notification_type' => :'NotificationType',
    :'sent_at' => :'sentAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 258

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 81

def self.openapi_types
  {
    :'version' => :'String',
    :'valid_from' => :'DateTime',
    :'application_id' => :'Integer',
    :'current_batch' => :'Integer',
    :'total_batches' => :'Integer',
    :'trigger' => :'StrikethroughTrigger',
    :'changed_items' => :'Array<StrikethroughChangedItem>',
    :'notification_type' => :'String',
    :'sent_at' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      valid_from == o.valid_from &&
      application_id == o.application_id &&
      current_batch == o.current_batch &&
      total_batches == o.total_batches &&
      trigger == o.trigger &&
      changed_items == o.changed_items &&
      notification_type == o.notification_type &&
      sent_at == o.sent_at
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 286

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 265

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 251

def hash
  [version, valid_from, application_id, current_batch, total_batches, trigger, changed_items, notification_type, sent_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 157

def list_invalid_properties
  invalid_properties = Array.new
  if @application_id.nil?
    invalid_properties.push('invalid value for "application_id", application_id cannot be nil.')
  end

  if @current_batch.nil?
    invalid_properties.push('invalid value for "current_batch", current_batch cannot be nil.')
  end

  if @total_batches.nil?
    invalid_properties.push('invalid value for "total_batches", total_batches cannot be nil.')
  end

  if @trigger.nil?
    invalid_properties.push('invalid value for "trigger", trigger cannot be nil.')
  end

  if @changed_items.nil?
    invalid_properties.push('invalid value for "changed_items", changed_items cannot be nil.')
  end

  if @notification_type.nil?
    invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.')
  end

  if @sent_at.nil?
    invalid_properties.push('invalid value for "sent_at", sent_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/talon_one/models/strikethrough_labeling_notification.rb', line 192

def valid?
  version_validator = EnumAttributeValidator.new('String', ["v2"])
  return false unless version_validator.valid?(@version)
  return false if @application_id.nil?
  return false if @current_batch.nil?
  return false if @total_batches.nil?
  return false if @trigger.nil?
  return false if @changed_items.nil?
  return false if @notification_type.nil?
  notification_type_validator = EnumAttributeValidator.new('String', ["StrikethroughPrice"])
  return false unless notification_type_validator.valid?(@notification_type)
  return false if @sent_at.nil?
  true
end