Class: TalonOne::UpdateCampaign

Inherits:
Object
  • Object
show all
Defined in:
lib/talon_one/models/update_campaign.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaign

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/talon_one/models/update_campaign.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::UpdateCampaign` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::UpdateCampaign`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'attributes')
    self.attributes = attributes[:'attributes']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'enabled'
  end

  if attributes.key?(:'active_ruleset_id')
    self.active_ruleset_id = attributes[:'active_ruleset_id']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'reevaluate_on_return')
    self.reevaluate_on_return = attributes[:'reevaluate_on_return']
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  end

  if attributes.key?(:'coupon_settings')
    self.coupon_settings = attributes[:'coupon_settings']
  end

  if attributes.key?(:'referral_settings')
    self.referral_settings = attributes[:'referral_settings']
  end

  if attributes.key?(:'limits')
    if (value = attributes[:'limits']).is_a?(Array)
      self.limits = value
    end
  end

  if attributes.key?(:'campaign_groups')
    if (value = attributes[:'campaign_groups']).is_a?(Array)
      self.campaign_groups = value
    end
  end

  if attributes.key?(:'evaluation_group_id')
    self.evaluation_group_id = attributes[:'evaluation_group_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'advanced'
  end

  if attributes.key?(:'linked_store_ids')
    if (value = attributes[:'linked_store_ids']).is_a?(Array)
      self.linked_store_ids = value
    end
  end

  if attributes.key?(:'coupon_attributes')
    self.coupon_attributes = attributes[:'coupon_attributes']
  end
end

Instance Attribute Details

#active_ruleset_idObject

[ID of Ruleset](docs.talon.one/management-api#tag/Campaigns/operation/getRulesets) this campaign applies on customer session evaluation.



36
37
38
# File 'lib/talon_one/models/update_campaign.rb', line 36

def active_ruleset_id
  @active_ruleset_id
end

#attributesObject

Arbitrary properties associated with this campaign.



30
31
32
# File 'lib/talon_one/models/update_campaign.rb', line 30

def attributes
  @attributes
end

#campaign_groupsObject

The IDs of the [campaign groups](docs.talon.one/docs/product/account/account-settings/managing-campaign-groups) this campaign belongs to.



55
56
57
# File 'lib/talon_one/models/update_campaign.rb', line 55

def campaign_groups
  @campaign_groups
end

#coupon_attributesObject

Arbitrary properties associated with coupons in this campaign.



67
68
69
# File 'lib/talon_one/models/update_campaign.rb', line 67

def coupon_attributes
  @coupon_attributes
end

#coupon_settingsObject

Returns the value of attribute coupon_settings.



47
48
49
# File 'lib/talon_one/models/update_campaign.rb', line 47

def coupon_settings
  @coupon_settings
end

#descriptionObject

A detailed description of the campaign.



21
22
23
# File 'lib/talon_one/models/update_campaign.rb', line 21

def description
  @description
end

#end_timeObject

Timestamp when the campaign will become inactive.



27
28
29
# File 'lib/talon_one/models/update_campaign.rb', line 27

def end_time
  @end_time
end

#evaluation_group_idObject

The ID of the campaign evaluation group the campaign belongs to.



58
59
60
# File 'lib/talon_one/models/update_campaign.rb', line 58

def evaluation_group_id
  @evaluation_group_id
end

#featuresObject

A list of features for the campaign.



45
46
47
# File 'lib/talon_one/models/update_campaign.rb', line 45

def features
  @features
end

#limitsObject

The set of limits that will operate for this campaign.



52
53
54
# File 'lib/talon_one/models/update_campaign.rb', line 52

def limits
  @limits
end

#linked_store_idsObject

A list of store IDs that you want to link to the campaign. > [!note] Note > - Campaigns with linked store IDs will only be evaluated when there is a > [customer session update](docs.talon.one/integration-api#tag/Customer-sessions/operation/updateCustomerSessionV2) > that references a linked store. > - If you linked stores to the campaign by uploading a CSV file, you cannot use this property and it should be empty. > - Use of this property is limited to 50 stores. To link more than 50 stores, upload them via a CSV file.



64
65
66
# File 'lib/talon_one/models/update_campaign.rb', line 64

def linked_store_ids
  @linked_store_ids
end

#nameObject

A user-facing name for this campaign.



18
19
20
# File 'lib/talon_one/models/update_campaign.rb', line 18

def name
  @name
end

#reevaluate_on_returnObject

Indicates whether this campaign should be reevaluated when a customer returns an item.



42
43
44
# File 'lib/talon_one/models/update_campaign.rb', line 42

def reevaluate_on_return
  @reevaluate_on_return
end

#referral_settingsObject

Returns the value of attribute referral_settings.



49
50
51
# File 'lib/talon_one/models/update_campaign.rb', line 49

def referral_settings
  @referral_settings
end

#start_timeObject

Timestamp when the campaign will become active.



24
25
26
# File 'lib/talon_one/models/update_campaign.rb', line 24

def start_time
  @start_time
end

#stateObject

A disabled or archived campaign is not evaluated for rules or coupons.



33
34
35
# File 'lib/talon_one/models/update_campaign.rb', line 33

def state
  @state
end

#tagsObject

A list of tags for the campaign.



39
40
41
# File 'lib/talon_one/models/update_campaign.rb', line 39

def tags
  @tags
end

#typeObject

The campaign type. Possible type values: - ‘cartItem`: Type of campaign that can apply effects only to cart items. - `advanced`: Type of campaign that can apply effects to customer sessions and cart items.



61
62
63
# File 'lib/talon_one/models/update_campaign.rb', line 61

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/talon_one/models/update_campaign.rb', line 92

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'attributes' => :'attributes',
    :'state' => :'state',
    :'active_ruleset_id' => :'activeRulesetId',
    :'tags' => :'tags',
    :'reevaluate_on_return' => :'reevaluateOnReturn',
    :'features' => :'features',
    :'coupon_settings' => :'couponSettings',
    :'referral_settings' => :'referralSettings',
    :'limits' => :'limits',
    :'campaign_groups' => :'campaignGroups',
    :'evaluation_group_id' => :'evaluationGroupId',
    :'type' => :'type',
    :'linked_store_ids' => :'linkedStoreIds',
    :'coupon_attributes' => :'couponAttributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



363
364
365
# File 'lib/talon_one/models/update_campaign.rb', line 363

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/talon_one/models/update_campaign.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/talon_one/models/update_campaign.rb', line 116

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'start_time' => :'DateTime',
    :'end_time' => :'DateTime',
    :'attributes' => :'Object',
    :'state' => :'String',
    :'active_ruleset_id' => :'Integer',
    :'tags' => :'Array<String>',
    :'reevaluate_on_return' => :'Boolean',
    :'features' => :'Array<String>',
    :'coupon_settings' => :'CodeGeneratorSettings',
    :'referral_settings' => :'CodeGeneratorSettings',
    :'limits' => :'Array<LimitConfig>',
    :'campaign_groups' => :'Array<Integer>',
    :'evaluation_group_id' => :'Integer',
    :'type' => :'String',
    :'linked_store_ids' => :'Array<Integer>',
    :'coupon_attributes' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/talon_one/models/update_campaign.rb', line 325

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      attributes == o.attributes &&
      state == o.state &&
      active_ruleset_id == o.active_ruleset_id &&
      tags == o.tags &&
      reevaluate_on_return == o.reevaluate_on_return &&
      features == o.features &&
      coupon_settings == o.coupon_settings &&
      referral_settings == o.referral_settings &&
      limits == o.limits &&
      campaign_groups == o.campaign_groups &&
      evaluation_group_id == o.evaluation_group_id &&
      type == o.type &&
      linked_store_ids == o.linked_store_ids &&
      coupon_attributes == o.coupon_attributes
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/talon_one/models/update_campaign.rb', line 391

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    TalonOne.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/talon_one/models/update_campaign.rb', line 460

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/talon_one/models/update_campaign.rb', line 370

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


350
351
352
# File 'lib/talon_one/models/update_campaign.rb', line 350

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



356
357
358
# File 'lib/talon_one/models/update_campaign.rb', line 356

def hash
  [name, description, start_time, end_time, attributes, state, active_ruleset_id, tags, reevaluate_on_return, features, coupon_settings, referral_settings, limits, campaign_groups, evaluation_group_id, type, linked_store_ids, coupon_attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/talon_one/models/update_campaign.rb', line 249

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @features.nil?
    invalid_properties.push('invalid value for "features", features cannot be nil.')
  end

  if @limits.nil?
    invalid_properties.push('invalid value for "limits", limits cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
# File 'lib/talon_one/models/update_campaign.rb', line 436

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/talon_one/models/update_campaign.rb', line 442

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



430
431
432
# File 'lib/talon_one/models/update_campaign.rb', line 430

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/talon_one/models/update_campaign.rb', line 276

def valid?
  return false if @name.nil?
  return false if @name.to_s.length < 1
  state_validator = EnumAttributeValidator.new('String', ["enabled", "disabled", "archived"])
  return false unless state_validator.valid?(@state)
  return false if @tags.nil?
  return false if @features.nil?
  return false if @limits.nil?
  type_validator = EnumAttributeValidator.new('String', ["cartItem", "advanced"])
  return false unless type_validator.valid?(@type)
  true
end