Class: TalonOne::AddedDeductedPointsNotification
- Inherits:
-
Object
- Object
- TalonOne::AddedDeductedPointsNotification
- Defined in:
- lib/talon_one/models/added_deducted_points_notification.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of added or deducted loyalty points.
-
#employee_name ⇒ Object
The name of the employee who added or deducted points.
-
#expiry_date ⇒ Object
The expiration date for loyalty points.
-
#loyalty_program_id ⇒ Object
The ID of the loyalty program.
-
#notification_type ⇒ Object
The type of notification.
-
#operation ⇒ Object
The action (addition or subtraction) made with loyalty points.
-
#profile_integration_id ⇒ Object
The integration ID of the customer profile to whom points were added or deducted.
-
#reason ⇒ Object
The reason for the points addition or deduction.
-
#session_integration_id ⇒ Object
The integration ID of the session through which the points were earned or lost.
-
#start_date ⇒ Object
The start date for loyalty points.
-
#subledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
-
#transaction_uuid ⇒ Object
The identifier of the transaction in the loyalty ledger.
-
#type_of_change ⇒ Object
The notification source, that is, it indicates whether the points were added or deducted via one of the following routes: - [The Campaign Manager](/docs/product/getting-started) - [Management API](/management-api#tag/Loyalty) - [Rule Engine](/docs/product/applications/evaluation-order-for-rules-and-filters).
-
#user_id ⇒ Object
The ID of the employee who added or deducted points.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddedDeductedPointsNotification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AddedDeductedPointsNotification
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::AddedDeductedPointsNotification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::AddedDeductedPointsNotification`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'employee_name') self.employee_name = attributes[:'employee_name'] end if attributes.key?(:'loyalty_program_id') self.loyalty_program_id = attributes[:'loyalty_program_id'] end if attributes.key?(:'notification_type') self.notification_type = attributes[:'notification_type'] end if attributes.key?(:'profile_integration_id') self.profile_integration_id = attributes[:'profile_integration_id'] end if attributes.key?(:'session_integration_id') self.session_integration_id = attributes[:'session_integration_id'] end if attributes.key?(:'subledger_id') self.subledger_id = attributes[:'subledger_id'] end if attributes.key?(:'type_of_change') self.type_of_change = attributes[:'type_of_change'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'operation') self.operation = attributes[:'operation'] end if attributes.key?(:'reason') self.reason = attributes[:'reason'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'transaction_uuid') self.transaction_uuid = attributes[:'transaction_uuid'] end end |
Instance Attribute Details
#amount ⇒ Object
The amount of added or deducted loyalty points.
42 43 44 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 42 def amount @amount end |
#employee_name ⇒ Object
The name of the employee who added or deducted points.
18 19 20 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 18 def employee_name @employee_name end |
#expiry_date ⇒ Object
The expiration date for loyalty points.
45 46 47 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 45 def expiry_date @expiry_date end |
#loyalty_program_id ⇒ Object
The ID of the loyalty program.
21 22 23 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 21 def loyalty_program_id @loyalty_program_id end |
#notification_type ⇒ Object
The type of notification.
24 25 26 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 24 def notification_type @notification_type end |
#operation ⇒ Object
The action (addition or subtraction) made with loyalty points.
48 49 50 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 48 def operation @operation end |
#profile_integration_id ⇒ Object
The integration ID of the customer profile to whom points were added or deducted.
27 28 29 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 27 def profile_integration_id @profile_integration_id end |
#reason ⇒ Object
The reason for the points addition or deduction.
51 52 53 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 51 def reason @reason end |
#session_integration_id ⇒ Object
The integration ID of the session through which the points were earned or lost.
30 31 32 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 30 def session_integration_id @session_integration_id end |
#start_date ⇒ Object
The start date for loyalty points.
54 55 56 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 54 def start_date @start_date end |
#subledger_id ⇒ Object
The ID of the subledger within the loyalty program where these points were added.
33 34 35 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 33 def subledger_id @subledger_id end |
#transaction_uuid ⇒ Object
The identifier of the transaction in the loyalty ledger.
57 58 59 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 57 def transaction_uuid @transaction_uuid end |
#type_of_change ⇒ Object
The notification source, that is, it indicates whether the points were added or deducted via one of the following routes: - [The Campaign Manager](/docs/product/getting-started) - [Management API](/management-api#tag/Loyalty) - [Rule Engine](/docs/product/applications/evaluation-order-for-rules-and-filters)
36 37 38 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 36 def type_of_change @type_of_change end |
#user_id ⇒ Object
The ID of the employee who added or deducted points.
39 40 41 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 39 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 82 def self.attribute_map { :'employee_name' => :'EmployeeName', :'loyalty_program_id' => :'LoyaltyProgramID', :'notification_type' => :'NotificationType', :'profile_integration_id' => :'ProfileIntegrationID', :'session_integration_id' => :'SessionIntegrationID', :'subledger_id' => :'SubledgerID', :'type_of_change' => :'TypeOfChange', :'user_id' => :'UserID', :'amount' => :'Amount', :'expiry_date' => :'ExpiryDate', :'operation' => :'Operation', :'reason' => :'Reason', :'start_date' => :'StartDate', :'transaction_uuid' => :'TransactionUUID' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
363 364 365 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 363 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 102 def self.openapi_types { :'employee_name' => :'String', :'loyalty_program_id' => :'Integer', :'notification_type' => :'String', :'profile_integration_id' => :'String', :'session_integration_id' => :'String', :'subledger_id' => :'String', :'type_of_change' => :'String', :'user_id' => :'Integer', :'amount' => :'Float', :'expiry_date' => :'DateTime', :'operation' => :'String', :'reason' => :'String', :'start_date' => :'DateTime', :'transaction_uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 329 def ==(o) return true if self.equal?(o) self.class == o.class && employee_name == o.employee_name && loyalty_program_id == o.loyalty_program_id && notification_type == o.notification_type && profile_integration_id == o.profile_integration_id && session_integration_id == o.session_integration_id && subledger_id == o.subledger_id && type_of_change == o.type_of_change && user_id == o.user_id && amount == o.amount && expiry_date == o.expiry_date && operation == o.operation && reason == o.reason && start_date == o.start_date && transaction_uuid == o.transaction_uuid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 391 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 460 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 370 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
350 351 352 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 350 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
356 357 358 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 356 def hash [employee_name, loyalty_program_id, notification_type, profile_integration_id, session_integration_id, subledger_id, type_of_change, user_id, amount, expiry_date, operation, reason, start_date, transaction_uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 201 def list_invalid_properties invalid_properties = Array.new if @employee_name.nil? invalid_properties.push('invalid value for "employee_name", employee_name cannot be nil.') end if @loyalty_program_id.nil? invalid_properties.push('invalid value for "loyalty_program_id", loyalty_program_id cannot be nil.') end if @loyalty_program_id < 1 invalid_properties.push('invalid value for "loyalty_program_id", must be greater than or equal to 1.') end if @notification_type.nil? invalid_properties.push('invalid value for "notification_type", notification_type cannot be nil.') end if @profile_integration_id.nil? invalid_properties.push('invalid value for "profile_integration_id", profile_integration_id cannot be nil.') end if @session_integration_id.nil? invalid_properties.push('invalid value for "session_integration_id", session_integration_id cannot be nil.') end if @subledger_id.nil? invalid_properties.push('invalid value for "subledger_id", subledger_id cannot be nil.') end if @type_of_change.nil? invalid_properties.push('invalid value for "type_of_change", type_of_change cannot be nil.') end if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @operation.nil? invalid_properties.push('invalid value for "operation", operation cannot be nil.') end if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end if @transaction_uuid.nil? invalid_properties.push('invalid value for "transaction_uuid", transaction_uuid cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
436 437 438 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 436 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 442 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
430 431 432 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 430 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/talon_one/models/added_deducted_points_notification.rb', line 260 def valid? return false if @employee_name.nil? return false if @loyalty_program_id.nil? return false if @loyalty_program_id < 1 return false if @notification_type.nil? notification_type_validator = EnumAttributeValidator.new('String', ["LoyaltyPointsDeducted", "LoyaltyPointsAdded"]) return false unless notification_type_validator.valid?(@notification_type) return false if @profile_integration_id.nil? return false if @session_integration_id.nil? return false if @subledger_id.nil? return false if @type_of_change.nil? type_of_change_validator = EnumAttributeValidator.new('String', ["campaign_manager", "rule_engine", "management_api"]) return false unless type_of_change_validator.valid?(@type_of_change) return false if @user_id.nil? return false if @amount.nil? return false if @operation.nil? operation_validator = EnumAttributeValidator.new('String', ["addition", "subtraction"]) return false unless operation_validator.valid?(@operation) return false if @reason.nil? return false if @transaction_uuid.nil? true end |