Class: TalonOne::GiveawayPoolNotificationData
- Inherits:
-
Object
- Object
- TalonOne::GiveawayPoolNotificationData
- Defined in:
- lib/talon_one/models/giveaway_pool_notification_data.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that owns the giveaway pool.
-
#application_id ⇒ Object
The ID of the Application connected to the giveaway pool.
-
#event ⇒ Object
The event type of the notification.
-
#pool_description ⇒ Object
The description of the giveaway pool.
-
#pool_id ⇒ Object
The ID of the giveaway pool.
-
#pool_name ⇒ Object
The name of the giveaway pool.
-
#remaining_codes ⇒ Object
The number of codes remaining in the giveaway pool.
-
#threshold_percent ⇒ Object
The percentage threshold for the notification.
-
#total_codes ⇒ Object
The total number of codes in the giveaway pool.
-
#used_codes ⇒ Object
The number of codes that have been used.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GiveawayPoolNotificationData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GiveawayPoolNotificationData
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TalonOne::GiveawayPoolNotificationData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TalonOne::GiveawayPoolNotificationData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'pool_id') self.pool_id = attributes[:'pool_id'] end if attributes.key?(:'pool_name') self.pool_name = attributes[:'pool_name'] end if attributes.key?(:'pool_description') self.pool_description = attributes[:'pool_description'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'total_codes') self.total_codes = attributes[:'total_codes'] end if attributes.key?(:'used_codes') self.used_codes = attributes[:'used_codes'] end if attributes.key?(:'remaining_codes') self.remaining_codes = attributes[:'remaining_codes'] end if attributes.key?(:'threshold_percent') self.threshold_percent = attributes[:'threshold_percent'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that owns the giveaway pool.
30 31 32 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 30 def account_id @account_id end |
#application_id ⇒ Object
The ID of the Application connected to the giveaway pool.
33 34 35 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 33 def application_id @application_id end |
#event ⇒ Object
The event type of the notification.
18 19 20 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 18 def event @event end |
#pool_description ⇒ Object
The description of the giveaway pool.
27 28 29 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 27 def pool_description @pool_description end |
#pool_id ⇒ Object
The ID of the giveaway pool.
21 22 23 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 21 def pool_id @pool_id end |
#pool_name ⇒ Object
The name of the giveaway pool.
24 25 26 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 24 def pool_name @pool_name end |
#remaining_codes ⇒ Object
The number of codes remaining in the giveaway pool.
42 43 44 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 42 def remaining_codes @remaining_codes end |
#threshold_percent ⇒ Object
The percentage threshold for the notification. The notification is triggered when the number of codes drops below this threshold.
45 46 47 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 45 def threshold_percent @threshold_percent end |
#total_codes ⇒ Object
The total number of codes in the giveaway pool.
36 37 38 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 36 def total_codes @total_codes end |
#used_codes ⇒ Object
The number of codes that have been used.
39 40 41 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 39 def used_codes @used_codes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 48 def self.attribute_map { :'event' => :'Event', :'pool_id' => :'PoolId', :'pool_name' => :'PoolName', :'pool_description' => :'PoolDescription', :'account_id' => :'AccountId', :'application_id' => :'ApplicationId', :'total_codes' => :'TotalCodes', :'used_codes' => :'UsedCodes', :'remaining_codes' => :'RemainingCodes', :'threshold_percent' => :'ThresholdPercent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 293 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 64 def self.openapi_types { :'event' => :'String', :'pool_id' => :'Integer', :'pool_name' => :'String', :'pool_description' => :'String', :'account_id' => :'Integer', :'application_id' => :'Integer', :'total_codes' => :'Integer', :'used_codes' => :'Integer', :'remaining_codes' => :'Integer', :'threshold_percent' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && event == o.event && pool_id == o.pool_id && pool_name == o.pool_name && pool_description == o.pool_description && account_id == o.account_id && application_id == o.application_id && total_codes == o.total_codes && used_codes == o.used_codes && remaining_codes == o.remaining_codes && threshold_percent == o.threshold_percent end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 321 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model TalonOne.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 390 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 300 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 286 def hash [event, pool_id, pool_name, pool_description, account_id, application_id, total_codes, used_codes, remaining_codes, threshold_percent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 143 def list_invalid_properties invalid_properties = Array.new if @event.nil? invalid_properties.push('invalid value for "event", event cannot be nil.') end if @pool_id.nil? invalid_properties.push('invalid value for "pool_id", pool_id cannot be nil.') end if @pool_id < 1 invalid_properties.push('invalid value for "pool_id", must be greater than or equal to 1.') end if @pool_name.nil? invalid_properties.push('invalid value for "pool_name", pool_name cannot be nil.') end if @pool_description.nil? invalid_properties.push('invalid value for "pool_description", pool_description cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @account_id < 1 invalid_properties.push('invalid value for "account_id", must be greater than or equal to 1.') end if @application_id.nil? invalid_properties.push('invalid value for "application_id", application_id cannot be nil.') end if @application_id < 1 invalid_properties.push('invalid value for "application_id", must be greater than or equal to 1.') end if @total_codes.nil? invalid_properties.push('invalid value for "total_codes", total_codes cannot be nil.') end if @used_codes.nil? invalid_properties.push('invalid value for "used_codes", used_codes cannot be nil.') end if @remaining_codes.nil? invalid_properties.push('invalid value for "remaining_codes", remaining_codes cannot be nil.') end if @threshold_percent.nil? invalid_properties.push('invalid value for "threshold_percent", threshold_percent cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
366 367 368 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 366 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 372 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
360 361 362 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 360 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/talon_one/models/giveaway_pool_notification_data.rb', line 202 def valid? return false if @event.nil? return false if @pool_id.nil? return false if @pool_id < 1 return false if @pool_name.nil? return false if @pool_description.nil? return false if @account_id.nil? return false if @account_id < 1 return false if @application_id.nil? return false if @application_id < 1 return false if @total_codes.nil? return false if @used_codes.nil? return false if @remaining_codes.nil? return false if @threshold_percent.nil? true end |